-- ****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5698-WSH
-- *
-- * (C) Copyright IBM Corp. 2002 - 2005.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- *
-- ****************************************************************************
-- *
-- * Product  : IBM Tivoli Workload Scheduler
-- *
-- * Component: Warehouse Enablement Pack
-- *
-- * File     : AWS_c10_s040_LoadCompAttr.db2
-- *
-- * Purpose  : ETL1 Load Attributes
-- *
-- ****************************************************************************
-- ETL1: Extract data from Tivoli Workload Scheduler temporary database
-- Transform and Load into Tivoli Enterprise Data Warehouse


----------------------------------
-- Create Staging Tables
----------------------------------

-------------------------------------------------------------------------------
-- Temporary Staging Comp Table
-------------------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp_Comp;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Temp_Comp
(
	Comp_Id		INTEGER not null,
	CompTyp_Cd	CHAR(17) not null,
	Comp_Nm		VARCHAR(254) not null,
	Comp_Corr_Val	VARCHAR(254) not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stg_Temp_Comp
(Comp_Id, CompTyp_Cd, Comp_Nm, Comp_Corr_Val)
select
	Comp.Comp_Id, Comp.CompTyp_Cd,
	Comp.Comp_Nm, Comp.Comp_Corr_Val
From
	Twg.Cur_Comp Comp
Where
	Comp.CompTyp_Cd = 'SCHED_WORKSTATION'
     or Comp.CompTyp_Cd = 'IP_HOST'
     or Comp.CompTyp_Cd = 'SCHED_JOBSTREAM'
     or Comp.CompTyp_Cd = 'SCHED_JOB';


-------------------------------------------------------------------------------
-- Temporary Staging CompAttr Table
-------------------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp_CompAttr;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Temp_CompAttr (
       Comp_Id              INTEGER not null,
       AttrTyp_Cd           CHAR(17) not null,
       CompAttr_Val         VARCHAR(254) not null
);

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Temp (
       Comp_Id              INTEGER not null,
       AttrTyp_Cd           CHAR(17) not null,
       CompAttr_Val         VARCHAR(254) not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stg_Temp
(Comp_Id, AttrTyp_Cd, CompAttr_Val)
select
	CompAttr.Comp_Id, CompAttr.AttrTyp_Cd, CompAttr.CompAttr_Val
From
	Twg.Cur_CompAttr CompAttr
Where
	CompAttr.AttrTyp_Cd = 'SCHED_WRKST_TYPE'
     or CompAttr.AttrTyp_Cd = 'LAST_IP_ADDRESS'
     or CompAttr.AttrTyp_Cd = 'OS_NAME'
     or CompAttr.AttrTyp_Cd = 'SCHED_DOMAIN'
     or CompAttr.AttrTyp_Cd = 'SCHED_PRIORITY'
     or CompAttr.AttrTyp_Cd = 'SCHED_LOGIN'
     or CompAttr.AttrTyp_Cd = 'SCHED_COMMAND';

--#EXECUTE_AT_TARGET
insert into Aws.Stg_Temp_CompAttr
(Comp_Id, AttrTyp_Cd, CompAttr_Val)
select
	CompAttr.Comp_Id, CompAttr.AttrTyp_Cd, CompAttr.CompAttr_Val
From
	Aws.Stg_Temp CompAttr,
	Aws.Stg_Temp_Comp TempComp
Where
	CompAttr.Comp_Id = TempComp.Comp_Id;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp;


-------------------------------------------------------------------------------
-- Temporary Input Tables
-------------------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Tmp_WorkStation;
 
--#EXECUTE_AT_TARGET
create table Aws.Tmp_WorkStation 
(
  Name  		  VARCHAR(96) not null,
  Node    		  VARCHAR(255),
  WorkstationType         VARCHAR(5),
  OperSys    		  VARCHAR(6),
  DomainName     	  VARCHAR(96),
  MasterName 		  VARCHAR(96),
  Symphony_Date           TIMESTAMP
);

--#EXECUTE_AT_TARGET
insert into Aws.Tmp_WorkStation
(Name, Node, WorkstationType, OperSys, DomainName, MasterName, Symphony_Date)
select
  Name,
  Node,
  WorkstationType,
  OperSys,
  DomainName,
  MasterName,
  min(Symphony_Date)
from Aws.Tws_Workstation_P
group by
  Name,
  Node,
  WorkstationType,
  OperSys,
  DomainName,
  MasterName;


--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Tmp_Job;

--#EXECUTE_AT_TARGET
create table Aws.Tmp_Job
(
  Name 			VARCHAR(96) not null,
  Priority		INTEGER,
  Actual_StartTime	TIMESTAMP,
  Login			VARCHAR(48),
  Command	  	VARCHAR(120),
  MasterName 		VARCHAR(96),
  WorkstationName       VARCHAR(96) not null,
  JobstreamName 	VARCHAR(96)
);

--#EXECUTE_AT_TARGET
insert into Aws.Tmp_Job
(Name, Priority, Actual_StartTime, Login, Command, MasterName, WorkstationName, JobstreamName)
select
  Name,
  Priority,
  min(Actual_StartTime),
  Login,
  Command,
  MasterName,
  WorkstationName,
  JobstreamName
from Aws.Tws_Job_P
group by
  Name,
  Priority,
  Login,
  Command,
  MasterName,
  WorkstationName,
  JobstreamName;


--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Tmp_JobStream;

--#EXECUTE_AT_TARGET
create table Aws.Tmp_JobStream
(
  Name 			VARCHAR(96) not null,
  Priority		INTEGER,
  Actual_StartTime	TIMESTAMP,
  MasterName 		VARCHAR(96) not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Tmp_JobStream
(Name, Priority, Actual_StartTime, MasterName)
select
  Name,
  Priority,
  min(Actual_StartTime),
  MasterName
from Aws.Tws_JobStream_P
group by
  Name,
  Priority,
  MasterName;



------------------------------------
-- insert into stage COMPATTR table
------------------------------------

-------------------------------------------------------------------------------
-- Workload Scheduler Workstation Attributes
-------------------------------------------------------------------------------
------------------------------------
-- Workstation type attributes
-- Attrtyp_Cd = 'SCHED_WRKST_TYPE'
------------------------------------
-- create staging table for new CompAttr
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompAttr;

--#EXECUTE_AT_TARGET
create table Aws.Stage_CompAttr
(
       Comp_Id              INTEGER not null,
       AttrTyp_Cd           CHAR(17) not null,
       CompAttr_Strt_DtTm   TIMESTAMP not null,
       CompAttr_Val         VARCHAR(254) not null
);
--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompAttr
(Comp_Id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_Val)
select distinct
    C.Comp_Id,
    'SCHED_WRKST_TYPE',
    A.Symphony_Date,
    coalesce(A.WorkstationType, ' ')
from
    Aws.Tmp_Workstation A,
    Aws.Stg_Temp_Comp C
where
	A.Name = C.Comp_Nm
    and C.Comptyp_Cd = 'SCHED_WORKSTATION'
    and C.Comp_Corr_Val = rtrim(substr(concat('SCHED_ENGINE - ', concat(A.MasterName, concat(' ,IP_HOST - ', A.Node))), 1, 254))
    and not exists (select 1
                    from Aws.Stg_Temp_CompAttr TempAttr
                    where
                    	TempAttr.Comp_Id = C.Comp_Id
                    and TempAttr.Attrtyp_Cd = 'SCHED_WRKST_TYPE'
	            and TempAttr.Compattr_Val = coalesce(A.WorkstationType, ' '));

-------------------------------------------------
-- Insert component attributes into CDW Table
-------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Twg.CompAttr
(Comp_Id, Attrtyp_Cd, Compattr_Strt_Dttm, Compattr_End_Dttm, Compattr_Val)
select
	StgAttr.Comp_Id, 
	StgAttr.Attrtyp_Cd,
	StgAttr.Compattr_Strt_Dttm,
	'9999-01-01-00.00.00.000000',
	StgAttr.Compattr_Val
from Aws.Stage_CompAttr StgAttr;


------------------------------------
-- Last Operating system name
-- Attrtyp_Cd = 'OS_NAME'
------------------------------------
-- create staging table for new CompAttr
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompAttr;

--#EXECUTE_AT_TARGET
create table Aws.Stage_CompAttr
(
       Comp_Id              INTEGER not null,
       AttrTyp_Cd           CHAR(17) not null,
       CompAttr_Strt_DtTm   TIMESTAMP not null,
       CompAttr_Val         VARCHAR(254) not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompAttr
(Comp_Id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_Val)
select distinct
    C.Comp_Id,
    'OS_NAME',
    A.Symphony_Date,
    coalesce(A.OperSys, ' ')
from
    Aws.Tmp_Workstation A,
    Aws.Stg_Temp_Comp C
where
	A.Name = C.Comp_Nm
    and C.CompTyp_Cd = 'SCHED_WORKSTATION'
    and C.Comp_Corr_Val = rtrim(substr(concat('SCHED_ENGINE - ', concat(A.MasterName, concat(' ,IP_HOST - ', A.Node))), 1, 254))
    and not exists (select 1
                    from Aws.Stg_Temp_CompAttr TempAttr
                    where
                    	TempAttr.Comp_Id = C.Comp_Id
                    and TempAttr.Attrtyp_Cd = 'OS_NAME'
	            and TempAttr.Compattr_Val = coalesce(A.OperSys, ' '));

-------------------------------------------------
-- Insert component attributes into CDW Table
-------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Twg.CompAttr
(Comp_Id, Attrtyp_Cd, Compattr_Strt_Dttm, Compattr_End_Dttm, Compattr_Val)
select
	StgAttr.Comp_Id, 
	StgAttr.Attrtyp_Cd,
	StgAttr.Compattr_Strt_Dttm,
	'9999-01-01-00.00.00.000000',
	StgAttr.Compattr_Val
from Aws.Stage_CompAttr StgAttr;


------------------------------------
-- Workload Scheduler Domain
-- Attrtyp_Cd = 'SCHED_DOMAIN'
------------------------------------
-- create staging table for new CompAttr
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompAttr;

--#EXECUTE_AT_TARGET
create table Aws.Stage_CompAttr
(
       Comp_Id              INTEGER not null,
       AttrTyp_Cd           CHAR(17) not null,
       CompAttr_Strt_DtTm   TIMESTAMP not null,
       CompAttr_Val         VARCHAR(254) not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompAttr
(Comp_Id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_Val)
select distinct
    C.Comp_Id,
    'SCHED_DOMAIN',
    A.Symphony_Date,
    coalesce(A.DomainName, ' ')
from
    Aws.Tmp_Workstation A,
    Aws.Stg_Temp_Comp C
where
	A.Name = C.Comp_Nm
    and C.CompTyp_Cd = 'SCHED_WORKSTATION'
    and C.Comp_Corr_Val = rtrim(substr(concat('SCHED_ENGINE - ', concat(A.MasterName, concat(' ,IP_HOST - ', A.Node))), 1, 254))
    and not exists (select 1
                    from Aws.Stg_Temp_CompAttr TempAttr
                    where
                    	TempAttr.Comp_Id = C.Comp_Id
                    and TempAttr.Attrtyp_Cd = 'SCHED_DOMAIN'
	            and TempAttr.Compattr_Val = coalesce(A.DomainName, ' '));

-------------------------------------------------
-- Insert component attributes into CDW Table
-------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Twg.CompAttr
(Comp_Id, Attrtyp_Cd, Compattr_Strt_Dttm, Compattr_End_Dttm, Compattr_Val)
select
	StgAttr.Comp_Id, 
	StgAttr.Attrtyp_Cd,
	StgAttr.Compattr_Strt_Dttm,
	'9999-01-01-00.00.00.000000',
	StgAttr.Compattr_Val
from Aws.Stage_CompAttr StgAttr;



-------------------------------------------------------------------------------
-- Workload Scheduler Job Attributes
-------------------------------------------------------------------------------
------------------------------------
-- Job Priority
-- Attrtyp_Cd = 'SCHED_PRIORITY'
------------------------------------
-- create staging table for new CompAttr
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompAttr;

--#EXECUTE_AT_TARGET
create table Aws.Stage_CompAttr
(
       Comp_Id              INTEGER not null,
       AttrTyp_Cd           CHAR(17) not null,
       CompAttr_Strt_DtTm   TIMESTAMP not null,
       CompAttr_Val         VARCHAR(254) not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompAttr
(Comp_Id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_Val)
select distinct
    C.Comp_Id,
    'SCHED_PRIORITY',
    A.Actual_StartTime,
    coalesce(rtrim(cast(A.Priority as CHAR(10))), ' ')
from
    Aws.Tmp_Job A,
    Aws.Stg_Temp_Comp C
where
	A.Name = C.Comp_Nm
    and C.CompTyp_Cd = 'SCHED_JOB'
    and C.Comp_Corr_Val = rtrim(substr(concat('SCHED_ENGINE - ', concat(A.MasterName, concat(' ,SCHED_WORKSTATION - ', concat(A.WorkstationName, concat(' ,SCHED_JOBSTREAM - ', A.JobstreamName))))), 1, 254))
    and not exists (select 1
                    from Aws.Stg_Temp_CompAttr TempAttr
                    where
                    	TempAttr.Comp_Id = C.Comp_Id
                    and TempAttr.Attrtyp_Cd = 'SCHED_PRIORITY'
	            and TempAttr.Compattr_Val = coalesce(rtrim(cast(A.Priority as CHAR(10))), ' '));

-------------------------------------------------
-- Insert component attributes into CDW Table
-------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Twg.CompAttr
(Comp_Id, Attrtyp_Cd, Compattr_Strt_Dttm, Compattr_End_Dttm, Compattr_Val)
select
	StgAttr.Comp_Id, 
	StgAttr.Attrtyp_Cd,
	StgAttr.Compattr_Strt_Dttm,
	'9999-01-01-00.00.00.000000',
	StgAttr.Compattr_Val
from Aws.Stage_CompAttr StgAttr;


------------------------------------
-- Login User Name
-- Attrtyp_Cd = 'SCHED_LOGIN'
------------------------------------
-- create staging table for new CompAttr
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompAttr;

--#EXECUTE_AT_TARGET
create table Aws.Stage_CompAttr
(
       Comp_Id              INTEGER not null,
       AttrTyp_Cd           CHAR(17) not null,
       CompAttr_Strt_DtTm   TIMESTAMP not null,
       CompAttr_Val         VARCHAR(254) not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompAttr
(Comp_Id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_Val)
select distinct
    C.Comp_Id,
    'SCHED_LOGIN',
    A.Actual_StartTime,
    coalesce(A.Login, ' ')
from
    Aws.Tmp_Job A,
    Aws.Stg_Temp_Comp C
where
	A.Name = C.Comp_Nm
    and C.CompTyp_Cd = 'SCHED_JOB'
    and C.Comp_Corr_Val = rtrim(substr(concat('SCHED_ENGINE - ', concat(A.MasterName, concat(' ,SCHED_WORKSTATION - ', concat(A.WorkstationName, concat(' ,SCHED_JOBSTREAM - ', A.JobstreamName))))), 1, 254))
    and not exists (select 1
                    from Aws.Stg_Temp_CompAttr TempAttr
                    where
                    	TempAttr.Comp_Id = C.Comp_Id
                    and TempAttr.Attrtyp_Cd = 'SCHED_LOGIN'
	            and TempAttr.Compattr_Val = coalesce(A.Login, ' '));
 
-------------------------------------------------
-- Insert component attributes into CDW Table
-------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Twg.CompAttr
(Comp_Id, Attrtyp_Cd, Compattr_Strt_Dttm, Compattr_End_Dttm, Compattr_Val)
select
	StgAttr.Comp_Id, 
	StgAttr.Attrtyp_Cd,
	StgAttr.Compattr_Strt_Dttm,
	'9999-01-01-00.00.00.000000',
	StgAttr.Compattr_Val
from Aws.Stage_CompAttr StgAttr;


------------------------------------
-- Command String
-- Attrtyp_Cd = 'SCHED_COMMAND'
------------------------------------
-- create staging table for new CompAttr
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompAttr;

--#EXECUTE_AT_TARGET
create table Aws.Stage_CompAttr
(
       Comp_Id              INTEGER not null,
       AttrTyp_Cd           CHAR(17) not null,
       CompAttr_Strt_DtTm   TIMESTAMP not null,
       CompAttr_Val         VARCHAR(254) not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompAttr
(Comp_Id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_Val)
select distinct
    C.Comp_Id,
    'SCHED_COMMAND',
    A.Actual_StartTime,
    coalesce(A.Command, ' ')
from
    Aws.Tmp_Job A,
    Aws.Stg_Temp_Comp C
where
	A.Name = C.Comp_Nm
    and C.CompTyp_Cd = 'SCHED_JOB'
    and C.Comp_Corr_Val = rtrim(substr(concat('SCHED_ENGINE - ', concat(A.MasterName, concat(' ,SCHED_WORKSTATION - ', concat(A.WorkstationName, concat(' ,SCHED_JOBSTREAM - ', A.JobstreamName))))), 1, 254))
    and not exists (select 1
                    from Aws.Stg_Temp_CompAttr TempAttr
                    where
                    	TempAttr.Comp_Id = C.Comp_Id
                    and TempAttr.Attrtyp_Cd = 'SCHED_COMMAND'
	            and TempAttr.Compattr_Val = coalesce(A.Command, ' '));


-------------------------------------------------
-- Insert component attributes into CDW Table
-------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Twg.CompAttr
(Comp_Id, Attrtyp_Cd, Compattr_Strt_Dttm, Compattr_End_Dttm, Compattr_Val)
select
	StgAttr.Comp_Id, 
	StgAttr.Attrtyp_Cd,
	StgAttr.Compattr_Strt_Dttm,
	'9999-01-01-00.00.00.000000',
	StgAttr.Compattr_Val
from Aws.Stage_CompAttr StgAttr;



-------------------------------------------------------------------------------
-- Workload Scheduler JobStream Attributes
-------------------------------------------------------------------------------
------------------------------------
-- JobStream Priority
-- Attrtyp_Cd = 'SCHED_PRIORITY'
------------------------------------
-- create staging table for new CompAttr
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompAttr;

--#EXECUTE_AT_TARGET
create table Aws.Stage_CompAttr
(
       Comp_Id              INTEGER not null,
       AttrTyp_Cd           CHAR(17) not null,
       CompAttr_Strt_DtTm   TIMESTAMP not null,
       CompAttr_Val         VARCHAR(254) not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompAttr
(Comp_Id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_Val)
select distinct
    C.Comp_Id,
    'SCHED_PRIORITY',
    A.Actual_StartTime,
    coalesce(rtrim(cast(A.Priority as CHAR(10))), ' ')
from
    Aws.Tmp_JobStream A,
    Aws.Stg_Temp_Comp C
where
	A.Name = C.Comp_Nm
    and C.CompTyp_Cd = 'SCHED_JOBSTREAM'
    and C.Comp_Corr_Val = concat('SCHED_ENGINE - ', A.MasterName)
    and not exists (select 1
                    from Aws.Stg_Temp_CompAttr TempAttr
                    where
                    	TempAttr.Comp_Id = C.Comp_Id
                    and TempAttr.Attrtyp_Cd = 'SCHED_PRIORITY'
	            and TempAttr.Compattr_Val = coalesce(rtrim(cast(A.Priority as CHAR(10))), ' '));

-------------------------------------------------
-- Insert component attributes into CDW Table
-------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Twg.CompAttr
(Comp_Id, Attrtyp_Cd, Compattr_Strt_Dttm, Compattr_End_Dttm, Compattr_Val)
select
	StgAttr.Comp_Id, 
	StgAttr.Attrtyp_Cd,
	StgAttr.Compattr_Strt_Dttm,
	'9999-01-01-00.00.00.000000',
	StgAttr.Compattr_Val
from Aws.Stage_CompAttr StgAttr;



-------------------------------------------------------------------------------
-- Workload Scheduler IP Host Attributes
-------------------------------------------------------------------------------
------------------------------------
-- Last Ip Address
-- Attrtyp_Cd = 'LAST_IP_ADDRESS'
------------------------------------
-- create staging table for new CompAttr
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompAttr;

--#EXECUTE_AT_TARGET
create table Aws.Stage_CompAttr
(
       Comp_Id              INTEGER not null,
       AttrTyp_Cd           CHAR(17) not null,
       CompAttr_Strt_DtTm   TIMESTAMP not null,
       CompAttr_Val         VARCHAR(254) not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompAttr
(Comp_Id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_Val)
select distinct
    C.Comp_Id,
    'LAST_IP_ADDRESS',
    A.Symphony_Date,
    coalesce(A.Node, ' ')
from
    Aws.Tmp_WorkStation A,
    Aws.Stg_Temp_Comp C
where
	A.Node = C.Comp_Nm
    and C.Comptyp_Cd = 'IP_HOST'
    and not exists (select 1
                    from Aws.Stg_Temp_CompAttr TempAttr
                    where
                    	TempAttr.Comp_Id = C.Comp_Id
                    and TempAttr.Attrtyp_Cd = 'LAST_IP_ADDRESS'
	            and TempAttr.Compattr_Val = coalesce(A.Node, ' '));

-------------------------------------------------
-- Insert component attributes into CDW Table
-------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Twg.CompAttr
(Comp_Id, Attrtyp_Cd, Compattr_Strt_Dttm, Compattr_End_Dttm, Compattr_Val)
select
	StgAttr.Comp_Id, 
	StgAttr.Attrtyp_Cd,
	StgAttr.Compattr_Strt_Dttm,
	'9999-01-01-00.00.00.000000',
	StgAttr.Compattr_Val
from Aws.Stage_CompAttr StgAttr;



-------------------------------------------------
-- drop staging tables
-------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompAttr;


-------------------------------------------------
-- drop temporary tables
-------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp_Comp;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp_CompAttr;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Tmp_WorkStation;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Tmp_JobStream;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Tmp_Job;


-- done ETL1 Attributes.