-- ****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5698-WSH
-- *
-- * (C) Copyright IBM Corp. 2002 - 2005.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- *
-- ****************************************************************************
-- *
-- * Product  : IBM Tivoli Workload Scheduler
-- *
-- * Component: Warehouse Enablement Pack
-- *
-- * File     : AWS_c10_s040_LoadComp.db2
-- *
-- * Purpose  : ETL1 Load Components
-- *
-- ****************************************************************************
-- ETL1: Extract data from Tivoli Workload Scheduler temporary database
-- Transform and Load into Tivoli Enterprise Data Warehouse


--------------------------------------------------------------------
-- create staging table for new AWS Components
--------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_Comp;

--#EXECUTE_AT_TARGET
create table Aws.Stage_Comp
(
       CompTyp_Cd           CHAR(17) not null,
       Centr_Cd             CHAR(6),
       Cust_Id              INTEGER,
       Comp_Nm              VARCHAR(254) not null,
       Comp_Corr_Val        VARCHAR(254),
       Comp_Ds              VARCHAR(254)
);


--------------------------------------------------------------------
-- create temporary staging table for AWS Components
--------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp_Comp;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Temp_Comp
(
       CompTyp_Cd           CHAR(17) not null,
       Comp_Nm              VARCHAR(254) not null,
       Comp_Corr_Val        VARCHAR(254)
);


--#EXECUTE_AT_TARGET
insert into Aws.Stg_Temp_Comp
(CompTyp_Cd, Comp_Nm, Comp_Corr_Val)
select
	CompTyp_Cd,
	Comp_Nm,
	Comp_Corr_Val
from
	Twg.Cur_Comp
where
	CompTyp_Cd = 'SCHED_ENGINE'
     or CompTyp_Cd = 'SCHED_WORKSTATION'
     or CompTyp_Cd = 'SCHED_JOB'
     or CompTyp_Cd = 'SCHED_JOBSTREAM'
     or CompTyp_Cd = 'IP_HOST'
     or CompTyp_Cd = 'IP_INTERFACE';


--------------------------------------------------------------------
-- insert into stage Component table TWS Components - Engine
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_Comp
(CompTyp_Cd, Centr_Cd, Cust_Id, Comp_Nm, Comp_Corr_Val, Comp_Ds)
select distinct                                                    
	'SCHED_ENGINE',
	Centr.Centr_Cd,
	Cust.Cust_Id,
	A.MasterName,
	'',
	'Master'
from
	Aws.Tws_Workstation_P A,
	Aws.Cust_Lookup Cust,
	Aws.Centr_Lookup Centr
where
	A.MasterName != ''
    and not exists (select 1
		    from Aws.Stg_Temp_Comp StgComp
		    where StgComp.CompTyp_Cd = 'SCHED_ENGINE'
		      and StgComp.Comp_Nm = A.MasterName
		      and StgComp.Comp_Corr_Val = '');


--------------------------------------------------------------------
-- insert into stage Component table TWS Components - Workstation
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_Comp
(CompTyp_Cd, Centr_Cd, Cust_Id, Comp_Nm, Comp_Corr_Val, Comp_Ds)
select distinct
	'SCHED_WORKSTATION',
	Centr.Centr_Cd,
	Cust.Cust_Id,
	A.Name,
	rtrim(substr(concat('SCHED_ENGINE - ', concat(A.MasterName, concat(' ,IP_HOST - ', A.Node))), 1, 254)),
	'WorkStation'
from
	Aws.Tws_Workstation_P A,
	Aws.Cust_Lookup Cust,
	Aws.Centr_Lookup Centr
where
	A.Name != ''
    and not exists (select 1
		    from Aws.Stg_Temp_Comp StgComp
		    where StgComp.CompTyp_Cd = 'SCHED_WORKSTATION'
		      and StgComp.Comp_Nm = A.Name
		      and StgComp.Comp_Corr_Val = rtrim(substr(concat('SCHED_ENGINE - ', concat(A.MasterName, concat(' ,IP_HOST - ', A.Node))), 1, 254)));


--------------------------------------------------------------------
-- insert into stage Component table TWS Components - Job
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_Comp
(CompTyp_Cd, Centr_Cd, Cust_Id, Comp_Nm, Comp_Corr_Val, Comp_Ds)
select distinct    
	'SCHED_JOB',
	Centr.Centr_Cd,
	Cust.Cust_Id,
	A.Name,
	rtrim(substr(concat('SCHED_ENGINE - ', concat(A.MasterName, concat(' ,SCHED_WORKSTATION - ', concat(A.WorkstationName, concat(' ,SCHED_JOBSTREAM - ', A.JobstreamName))))), 1, 254)),
	'Job'
from
	Aws.Tws_Job_P A,
	Aws.Cust_Lookup Cust,
	Aws.Centr_Lookup Centr
where
	A.Name != ''
    and not exists (select 1
		    from Aws.Stg_Temp_Comp StgComp
		    where StgComp.CompTyp_Cd = 'SCHED_JOB'
		      and StgComp.Comp_Nm = A.Name
		      and StgComp.Comp_Corr_Val = rtrim(substr(concat('SCHED_ENGINE - ', concat(A.MasterName, concat(' ,SCHED_WORKSTATION - ', concat(A.WorkstationName, concat(' ,SCHED_JOBSTREAM - ', A.JobstreamName))))), 1, 254)));


--------------------------------------------------------------------
-- insert into stage Component table TWS Components  - Job Stream
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_Comp
(CompTyp_Cd, Centr_Cd, Cust_Id, Comp_Nm, Comp_Corr_Val, Comp_Ds)
select distinct   
	'SCHED_JOBSTREAM',
	Centr.Centr_Cd,
	Cust.Cust_Id,
	A.Name,
	concat('SCHED_ENGINE - ', A.MasterName),
	'Job Stream'
from 
	Aws.Tws_Jobstream_P A,
	Aws.Cust_Lookup Cust,
	Aws.Centr_Lookup Centr
where
	A.Name != ''
    and not exists (select 1
		    from Aws.Stg_Temp_Comp StgComp
		    where StgComp.CompTyp_Cd = 'SCHED_JOBSTREAM'
		      and StgComp.Comp_Nm = A.Name
		      and StgComp.Comp_Corr_Val = concat('SCHED_ENGINE - ', A.MasterName));


--------------------------------------------------------------------
-- insert into stage Component table TWS Components - Ip Host
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_Comp
(CompTyp_Cd, Centr_Cd, Cust_Id, Comp_Nm, Comp_Corr_Val, Comp_Ds)
select distinct    
	'IP_HOST',
	Centr.Centr_Cd,
	Cust.Cust_Id,
	A.Node,
	'',
	'IP Host'
from
	Aws.Tws_Workstation_P A,
	Aws.Cust_Lookup Cust,
	Aws.Centr_Lookup Centr
where
	A.Node != ''
    and not exists (select 1
		    from Aws.Stg_Temp_Comp StgComp
		    where StgComp.CompTyp_Cd = 'IP_HOST'
		      and StgComp.Comp_Nm = A.Node
		      and StgComp.Comp_Corr_Val = '');


--------------------------------------------------------------------
-- insert into stage Component table TWS Components - Ip Interface
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_Comp
(CompTyp_Cd, Centr_Cd, Cust_Id, Comp_Nm, Comp_Corr_Val, Comp_Ds)
select distinct    
	'IP_INTERFACE',
	Centr.Centr_Cd,
	Cust.Cust_Id,
	A.Node,
	'',
	'IP Interface'
from 
	Aws.Tws_Workstation_P A,
	Aws.Cust_Lookup Cust,
	Aws.Centr_Lookup Centr
where                                                                     
	A.Node != ''
    and not exists (select 1
		    from Aws.Stg_Temp_Comp StgComp
		    where StgComp.CompTyp_Cd = 'IP_INTERFACE'
		      and StgComp.Comp_Nm = A.Node
		      and StgComp.Comp_Corr_Val = '');


--------------------------------------------------------------------
-- insert components into final table
-------------------------------------------------------------------- 
--#EXECUTE_AT_TARGET
insert into Twg.Comp
(Comptyp_Cd, Centr_Cd, Cust_Id, Comp_Nm, Comp_Corr_Val, Comp_Strt_Dttm, Comp_End_Dttm, Comp_Ds)
select
	StageComp.CompTyp_Cd,
	StageComp.Centr_Cd,
	StageComp.Cust_Id,
	StageComp.Comp_Nm,
	StageComp.Comp_Corr_Val,
	Current TimeStamp - Current TimeZone,
	'9999-01-01-00.00.00.000000',
	StageComp.Comp_Ds
from
	Aws.Stage_Comp As StageComp;


--------------------------------------------------------------------
-- drop staging tables
--------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_Comp;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp_Comp;


-- done ETL1 Component.