-- ****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5698-WSH
-- *
-- * (C) Copyright IBM Corp. 2002 - 2005.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- *
-- ****************************************************************************
-- *
-- * Product  : IBM Tivoli Workload Scheduler
-- *
-- * Component: Warehouse Enablement Pack
-- *
-- * File     : AWS_c10_s040_LoadCompReln.db2
-- *
-- * Purpose  : ETL1 Load Relationships
-- *
-- ****************************************************************************
-- ETL1: Extract data from Tivoli Workload Scheduler temporary database
-- Transform and Load into Tivoli Enterprise Data Warehouse


--------------------------------------------------------------------
-- create temporary staging table for AWS Relationships
--------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompReln;

--#EXECUTE_AT_TARGET
create table Aws.Stage_CompReln
(
       Comp_Source_Id       INTEGER not null,
       Comp_Target_Id       INTEGER not null,
       RelnTyp_Cd           CHAR(6)
);


--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_CompReln;

--#EXECUTE_AT_TARGET
create table Aws.Stg_CompReln
(
       Comp_Source_Id       INTEGER not null,
       Comp_Target_Id       INTEGER not null,
       RelnTyp_Cd           CHAR(6)
);


--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Comp;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Comp
(
       Comp_Id              INTEGER,
       CompTyp_Cd           CHAR(17) not null,
       Comp_Nm              VARCHAR(254) not null,
       Comp_Corr_Val        VARCHAR(254)
);


------------------------------------
-- insert into staging tables
------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stg_Comp
(Comp_Id, CompTyp_Cd, Comp_Nm, Comp_Corr_Val)
select
	Comp_Id,
	CompTyp_Cd,
	Comp_Nm,
	Comp_Corr_Val
from
	Twg.Cur_Comp
where
	CompTyp_Cd = 'SCHED_ENGINE'
     or CompTyp_Cd = 'SCHED_WORKSTATION'
     or CompTyp_Cd = 'SCHED_JOB'
     or CompTyp_Cd = 'SCHED_JOBSTREAM'
     or CompTyp_Cd = 'IP_HOST';


--#EXECUTE_AT_TARGET
insert into Aws.Stg_CompReln
(Comp_Source_Id, Comp_Target_Id, RelnTyp_Cd)
select
	CompReln.Comp_Source_Id,
	CompReln.Comp_Target_Id,
	CompReln.RelnTyp_Cd
from
	Twg.Cur_CompReln CompReln
where
	exists (select 1
		from Aws.Stg_Comp StgComp
	        where StgComp.Comp_Id = CompReln.Comp_Source_Id)
    and exists (select 1
    		from Aws.Stg_Comp StgComp
    		where StgComp.Comp_Id = CompReln.Comp_Target_Id);


--------------------------------------------------------------------
-- insert into COMPRELN table PCHILD relation
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompReln
(Comp_Source_Id, Comp_Target_Id, RelnTyp_Cd)
select
	SourceComp.Comp_Id,
	TargetComp.Comp_Id,
	'PCHILD'
from
	Aws.Stg_Comp SourceComp,
	Aws.Stg_Comp TargetComp
where
	SourceComp.CompTyp_Cd = 'SCHED_ENGINE'
    and (TargetComp.CompTyp_Cd = 'SCHED_WORKSTATION' or
         TargetComp.CompTyp_Cd = 'SCHED_JOB' or
         TargetComp.CompTyp_Cd = 'SCHED_JOBSTREAM')
    and SourceComp.Comp_Nm = substr(
	      	rtrim(ltrim(substr(TargetComp.Comp_Corr_Val,
            	locate ('SCHED_ENGINE - ',TargetComp.Comp_Corr_Val)+
		length('SCHED_ENGINE - ')))),1,
		locate(' ',rtrim(ltrim (substr(TargetComp.Comp_Corr_Val,
		locate('SCHED_ENGINE - ',TargetComp.Comp_Corr_Val)+length('SCHED_ENGINE - '))))))
    and not exists (select 1
    		    from Aws.Stg_CompReln StgCompReln
    		    where
    		    	StgCompReln.Comp_Source_Id = SourceComp.Comp_Id
                    and StgCompReln.Comp_Target_Id = TargetComp.Comp_Id
                    and StgCompReln.RelnTyp_Cd = 'PCHILD');


--------------------------------------------------------------------
-- insert into COMPRELN table LCONT relation
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompReln
(Comp_Source_Id, Comp_Target_Id, RelnTyp_Cd)
select
	SourceComp.Comp_Id,
	TargetComp.Comp_Id,
	'LCONT'
from
	Aws.Stg_Comp SourceComp,
	Aws.Stg_Comp TargetComp
where
	SourceComp.CompTyp_Cd = 'SCHED_JOB'
    and TargetComp.CompTyp_Cd = 'SCHED_JOBSTREAM'
    and TargetComp.Comp_Nm = rtrim(ltrim(substr
    		(SourceComp.Comp_Corr_Val, locate ('SCHED_JOBSTREAM -',
    		 SourceComp.Comp_Corr_Val)+length('SCHED_JOBSTREAM -'))))
    and not exists (select 1
    		    from Aws.Stg_CompReln StgCompReln
    		    where
                   	StgCompReln.Comp_Source_Id = SourceComp.Comp_Id
                    and StgCompReln.Comp_Target_Id = TargetComp.Comp_Id
                    and StgCompReln.RelnTyp_Cd = 'LCONT');


--------------------------------------------------------------------
-- insert into COMPRELN table RUNSON relation
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompReln
(Comp_Source_Id, Comp_Target_Id, RelnTyp_Cd)
select
	SourceComp.Comp_Id,
	TargetComp.Comp_Id,
	'RUNSON'
from
	Aws.Stg_Comp SourceComp,
	Aws.Stg_Comp TargetComp
where
	((TargetComp.CompTyp_Cd = 'SCHED_WORKSTATION' and
	  SourceComp.CompTyp_Cd = 'SCHED_JOB' and
	  TargetComp.Comp_Nm = substr(
	  	rtrim(ltrim (substr(SourceComp.Comp_Corr_Val,locate
	  	('SCHED_WORKSTATION -',SourceComp.Comp_Corr_Val)+
	  	length('SCHED_WORKSTATION -')))),1,locate(' ',rtrim(ltrim
	  	(substr(SourceComp.Comp_Corr_Val,locate
	  	('SCHED_WORKSTATION -',SourceComp.Comp_Corr_Val)+
	  	length('SCHED_WORKSTATION -')))))	
	  ))
    or
         (TargetComp.CompTyp_Cd = 'IP_HOST' and
          SourceComp.CompTyp_Cd = 'SCHED_WORKSTATION' and
          TargetComp.Comp_Nm = rtrim(ltrim(substr(SourceComp.Comp_Corr_Val,
          	locate ('IP_HOST - ',SourceComp.Comp_Corr_Val)+
          	length('IP_HOST - '))))))
    and not exists (select 1
    		    from Aws.Stg_CompReln StgCompReln
    		    where
                   	StgCompReln.Comp_Source_Id = SourceComp.Comp_Id
                    and StgCompReln.Comp_Target_Id = TargetComp.Comp_Id
                    and StgCompReln.RelnTyp_Cd = 'RUNSON');


--------------------------------------------------------------------
-- insert components into final table
-------------------------------------------------------------------- 
--#EXECUTE_AT_TARGET
insert into Twg.CompReln
(Comp_Source_Id, Comp_Target_Id, RelnTyp_Cd, CompReln_Strt_Dttm, CompReln_End_Dttm)
select
	StageCompReln.Comp_Source_Id,
	StageCompReln.Comp_Target_Id,
	StageCompReln.RelnTyp_Cd,
	Current TimeStamp - Current TimeZone,
	'9999-01-01-00.00.00.000000'
from
	Aws.Stage_CompReln StageCompReln;


--------------------------------------------------------------------
-- drop staging tables
--------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompReln;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Comp;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_CompReln;


-- done ETL1 Relationship.