-- ****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5698-WSH
-- *
-- * (C) Copyright IBM Corp. 2002 - 2005.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- *
-- ****************************************************************************
-- *
-- * Product  : IBM Tivoli Workload Scheduler
-- *
-- * Component: Warehouse Enablement Pack
-- *
-- * File     : AWS_c10_s50_LoadMsmt.db2
-- *
-- * Purpose  : ETL1 Load Measurements
-- *
-- ****************************************************************************
-- ETL1: Extract data from Tivoli Workload Scheduler temporary database
-- Transform and Load into Tivoli Enterprise Data Warehouse


--------------------------------------------------------------------
-- create staging tables
--------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_Msmt;

--#EXECUTE_AT_TARGET
create table Aws.Stage_Msmt
(
       Comp_Id              INTEGER,
       MsmtTyp_Id           INTEGER,
       TmSum_Cd             CHAR,
       Msmt_Strt_Dt         DATE,
       Msmt_Strt_Tm         TIME,
       Msmt_Min_Val         FLOAT,
       Msmt_Max_Val         FLOAT,
       Msmt_Avg_Val         FLOAT,
       Msmt_Tot_Val         FLOAT
);


--------------------------------------------------------------------
-- create temporary staging table for AWS Components
--------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp_Comp;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Temp_Comp
(
       Comp_Id              INTEGER not null,
       CompTyp_Cd           CHAR(17) not null,
       Comp_Nm              VARCHAR(254) not null,
       Comp_Corr_Val        VARCHAR(254)
);

--#EXECUTE_AT_TARGET
insert into Aws.Stg_Temp_Comp
(Comp_Id, CompTyp_Cd, Comp_Nm, Comp_Corr_Val)
select
	Comp_Id,
	CompTyp_Cd,
	Comp_Nm,
	Comp_Corr_Val
from
	Twg.Cur_Comp
where
	CompTyp_Cd = 'SCHED_ENGINE'
     or CompTyp_Cd = 'SCHED_WORKSTATION'
     or CompTyp_Cd = 'SCHED_JOB'
     or CompTyp_Cd = 'SCHED_JOBSTREAM'
     or CompTyp_Cd = 'IP_HOST'
     or CompTyp_Cd = 'IP_INTERFACE';


--------------------------------------------------------------------
-- create temporary table
--------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Temp
(
       Comp_Id              INTEGER not null,
       CompTyp_Cd           CHAR(17) not null,
       Comp_Nm              VARCHAR(254) not null,
       Comp_Corr_Val        VARCHAR(254),
       MsmtTyp_Id           INTEGER not null,
       MsmtTyp_Nm           VARCHAR(120),
       TmSum_Cd             CHAR(1) not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stg_Temp
(Comp_Id, CompTyp_Cd, Comp_Nm, Comp_Corr_Val, MsmtTyp_Id, MsmtTyp_Nm, TmSum_Cd)
select
	Comp.Comp_Id, Comp.CompTyp_Cd, Comp.Comp_Nm, Comp.Comp_Corr_Val,
	MsmtTyp.MsmtTyp_Id, MsmtTyp.MsmtTyp_Nm, 'D'
from
	Aws.Stg_Temp_Comp Comp, Twg.MsmtRul MsmtRul, Twg.MsmtTyp MsmtTyp
	
where   MsmtTyp.MsmtTyp_Id = MsmtRul.MsmtTyp_Id
    and MsmtRul.CompTyp_Cd = Comp.CompTyp_Cd;

--------------------------------------------------------------------
-- insert Measurements for Jobs
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_Msmt
(Comp_Id, MsmtTyp_Id, TmSum_Cd, Msmt_Strt_Dt, Msmt_Strt_Tm,
 Msmt_Min_Val, Msmt_Max_Val, Msmt_Avg_Val, Msmt_Tot_Val)
select
  Temp.Comp_Id,
  Temp.MsmtTyp_Id,
  Temp.TmSum_Cd,
  coalesce(date(Job.Actual_StartTime), date(Job.Planned_StartTime)),
  coalesce(time(Job.Actual_StartTime), time(Job.Planned_StartTime)),
  
  case Temp.MsmtTyp_Nm
     when 'Start Delay'
        then value(min(Job.Actual_StartTime-Job.Planned_StartTime), 0)
     when 'Duration'
        then value(min(Job.Actual_Duration), 0)
     when 'CPU Time'
        then value(min(Job.Cpu_Time), 0)
     else cast(null as double)
  end,

  case Temp.MsmtTyp_Nm
     when 'Start Delay'
        then value(max(Job.Actual_StartTime-Job.Planned_StartTime), 0)
     when 'Duration'
        then value(max(Job.Actual_Duration), 0)
     when 'CPU Time'
        then value(max(Job.Cpu_Time), 0)
     else cast(null as double)
  end,

  case Temp.MsmtTyp_Nm
     when 'Start Delay'
        then value(avg(year(Job.Actual_StartTime-Job.Planned_StartTime)*31536000+month(Job.Actual_StartTime-Job.Planned_StartTime)*2592000+day(Job.Actual_StartTime-Job.Planned_StartTime)*86400+hour(Job.Actual_StartTime-Job.Planned_StartTime)*3600+minute(Job.Actual_StartTime-Job.Planned_StartTime)*60+second(Job.Actual_StartTime-Job.Planned_StartTime)),0)
     when 'Duration'
        then value(avg(Job.Actual_Duration), 0)
     when 'CPU Time'
        then value(avg(Job.Cpu_Time), 0)
     else cast(null as double)
  end,

  case Temp.MsmtTyp_Nm
     when 'Number of Successful Runs'
        then count(distinct Temp.Comp_Id)
     when 'Number of Unsuccessful Runs'
        then count(distinct Temp.Comp_Id)
     when 'Number of Canceled Runs'
        then count(distinct Temp.Comp_Id)
     when 'Number of Unknown Runs'
        then count(distinct Temp.Comp_Id)
     when 'Number of Runs'
        then count(distinct Temp.Comp_Id)
     else cast(null as double)
  end

from
  Aws.Tws_Job_P Job,
  Aws.Stg_Temp Temp

where
      Temp.Comp_Nm = Job.Name
  and Temp.CompTyp_Cd = 'SCHED_JOB'
  and Temp.Comp_Corr_Val = rtrim(substr(concat('SCHED_ENGINE - ', concat(Job.MasterName, concat(' ,SCHED_WORKSTATION - ', concat(Job.WorkstationName, concat(' ,SCHED_JOBSTREAM - ', Job.JobstreamName))))), 1, 254))
  and ((Temp.MsmtTyp_Nm = 'Number of Successful Runs' and Job.Status = 6 ) or
       (Temp.MsmtTyp_Nm = 'Number of Unsuccessful Runs' and Job.Status in (5,13,28)) or
       (Temp.MsmtTyp_Nm = 'Number of Canceled Runs' and Job.Status in (7,10)) or
       (Temp.MsmtTyp_Nm = 'Number of Unknown Runs' and Job.Status in(8,27)) or
       (Temp.MsmtTyp_Nm = 'Number of Runs' and Job.Status IN (3,5,6,7,8,9,12,17,18,19,20,23,24,25,27,28)) or
       (Temp.MsmtTyp_Nm = 'Start Delay' and timestampdiff(2, cast(Job.Actual_StartTime-Job.Planned_StartTime as char(22))) > 0) or
       (Temp.MsmtTyp_Nm = 'Duration' and  Job.Actual_Duration > 0) or
       (Temp.MsmtTyp_Nm = 'CPU Time' and Job.Cpu_Time > 0))

group by
  Temp.Comp_Id,
  Temp.MsmtTyp_Id,
  Temp.MsmtTyp_Nm,
  Temp.TmSum_Cd,
  Job.Actual_StartTime,
  Job.Planned_StartTime;
 

--------------------------------------------------------------------
-- insert Duration, Start Delay and CPU Time Measurements for Jobs 
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_Msmt
(Comp_Id, MsmtTyp_Id, TmSum_Cd, Msmt_Strt_Dt,
 Msmt_Strt_Tm, Msmt_Tot_Val)
select
  Temp.Comp_Id,
  Temp.MsmtTyp_Id,
  Temp.TmSum_Cd,
  coalesce(date(Job.Actual_StartTime), date(Job.Planned_StartTime)),
  coalesce(time(Job.Actual_StartTime), time(Job.Planned_StartTime)),
  
  case Temp.MsmtTyp_Nm
     when 'Start Delay'
        then value(sum(timestampdiff(2, cast(Job.Actual_StartTime-Job.Planned_StartTime as char(22)))), 0)
     when 'Duration'
        then value(sum(Job.Actual_Duration), 0)
     when 'CPU Time'
        then value(sum(Job.Cpu_Time), 0)
     else cast(null as double)
  end

from
  Aws.Tws_Job_P Job,
  Aws.Stg_Temp Temp

where
      Temp.Comp_Nm = Job.Name
  and Temp.CompTyp_Cd = 'SCHED_JOB'
  and Temp.Comp_Corr_Val = rtrim(substr(concat('SCHED_ENGINE - ', concat(Job.MasterName, concat(' ,SCHED_WORKSTATION - ', concat(Job.WorkstationName, concat(' ,SCHED_JOBSTREAM - ', Job.JobstreamName))))), 1, 254))
  and ((Temp.MsmtTyp_Nm = 'Start Delay' and timestampdiff(2, cast(Job.Actual_StartTime-Job.Planned_StartTime as char(22))) > 0) or
       (Temp.MsmtTyp_Nm = 'Duration' and  Job.Actual_Duration > 0) or
       (Temp.MsmtTyp_Nm = 'CPU Time' and Job.Cpu_Time > 0))

group by
  Temp.Comp_Id,
  Temp.MsmtTyp_Id,
  Temp.MsmtTyp_Nm,
  Temp.TmSum_Cd,
  Job.Actual_StartTime,
  Job.Planned_StartTime;


--------------------------------------------------------------------
-- insert Measurements for Job streams
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_Msmt
(Comp_Id, MsmtTyp_Id, TmSum_Cd, Msmt_Strt_Dt, Msmt_Strt_Tm,
 Msmt_Min_Val, Msmt_Max_Val, Msmt_Avg_Val, Msmt_Tot_Val)
select
  Temp.Comp_Id,
  Temp.MsmtTyp_Id,
  Temp.TmSum_Cd,
  coalesce(date(Job.Actual_StartTime), date(Job.Planned_StartTime)),
  coalesce(time(Job.Actual_StartTime), time(Job.Planned_StartTime)),
  
  case Temp.MsmtTyp_Nm
     when 'Start Delay'
        then value(min(Job.Actual_StartTime-Job.Planned_StartTime), 0)
     when 'Duration'
        then value(min(Job.Actual_Duration), 0)
     when 'CPU Time'
        then value(min(Job.Cpu_Time), 0)
     else cast(null as double)
  end,

  case Temp.MsmtTyp_Nm
     when 'Start Delay'
        then value(max(Job.Actual_StartTime-Job.Planned_StartTime), 0)
     when 'Duration'
        then value(max(Job.Actual_Duration), 0)
     when 'CPU Time'
        then value(max(Job.Cpu_Time), 0)
     else cast(null as double)
  end,

  case Temp.MsmtTyp_Nm
     when 'Start Delay'
        then value(avg(Job.Actual_StartTime-Job.Planned_StartTime), 0)
     when 'Duration'
        then value(avg(Job.Actual_Duration), 0)
     when 'CPU Time'
        then value(avg(Job.Cpu_Time), 0)
     else cast(null as double)
  end,

  case Temp.MsmtTyp_Nm
     when 'Number of Successful Runs'
        then count(distinct Temp.Comp_Id)
     when 'Number of Unsuccessful Runs'
        then count(distinct Temp.Comp_Id)
     when 'Number of Canceled Runs'
        then count(distinct Temp.Comp_Id)
     when 'Number of Unknown Runs'
        then count(distinct Temp.Comp_Id)
     when 'Number of Runs'
        then count(distinct Temp.Comp_Id)
     else cast(null as double)
  end

from
  Aws.Tws_JobStream_P Job,
  Aws.Stg_Temp Temp

where
      Temp.Comp_Nm = Job.Name
  and Temp.CompTyp_Cd = 'SCHED_JOBSTREAM'
  and Temp.Comp_Corr_Val = concat('SCHED_ENGINE - ', Job.MasterName)
  and ((Temp.MsmtTyp_Nm = 'Number of Successful Runs' and Job.Status = 6 ) or
       (Temp.MsmtTyp_Nm = 'Number of Unsuccessful Runs' and Job.Status in (5,13,28)) or
       (Temp.MsmtTyp_Nm = 'Number of Canceled Runs' and Job.Status in (7,10)) or
       (Temp.MsmtTyp_Nm = 'Number of Unknown Runs' and Job.Status in(8,27)) or
       (Temp.MsmtTyp_Nm = 'Number of Runs' and Job.Status IN (3,5,6,7,8,9,12,17,18,19,20,23,24,25,27,28)) or
       (Temp.MsmtTyp_Nm = 'Start Delay' and timestampdiff(2, cast(Job.Actual_StartTime-Job.Planned_StartTime as char(22))) > 0) or
       (Temp.MsmtTyp_Nm = 'Duration' and  Job.Actual_Duration > 0) or
       (Temp.MsmtTyp_Nm = 'CPU Time' and Job.Cpu_Time > 0))

group by
  Temp.Comp_Id,
  Temp.MsmtTyp_Id,
  Temp.MsmtTyp_Nm,
  Temp.TmSum_Cd,
  Job.Actual_StartTime,
  Job.Planned_StartTime;


--------------------------------------------------------------------
-- insert Duration and start delay Measurements for Job streams
--------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Stage_Msmt
(Comp_Id, MsmtTyp_Id, TmSum_Cd, Msmt_Strt_Dt,
 Msmt_Strt_Tm, Msmt_Avg_Val, Msmt_Tot_Val)
select
  Temp.Comp_Id,
  Temp.MsmtTyp_Id,
  Temp.TmSum_Cd,
  coalesce(date(Job.Actual_StartTime), date(Job.Planned_StartTime)),
  coalesce(time(Job.Actual_StartTime), time(Job.Planned_StartTime)),
  
  case Temp.MsmtTyp_Nm
     when 'Start Delay'
        then value(sum(timestampdiff(2, cast(Job.Actual_StartTime-Job.Planned_StartTime as char(22)))), 0)
     when 'Duration'
        then value(sum(Job.Actual_Duration), 0)
     when 'CPU Time'
        then value(sum(Job.Cpu_Time), 0)
     else cast(null as double)
  end,
  
  case Temp.MsmtTyp_Nm
     when 'Start Delay'
        then value(sum(timestampdiff(2, cast(Job.Actual_StartTime-Job.Planned_StartTime as char(22)))), 0)
     when 'Duration'
        then value(sum(Job.Actual_Duration), 0)
     when 'CPU Time'
        then value(sum(Job.Cpu_Time), 0)
     else cast(null as double)
  end

from
  Aws.Tws_JobStream_P Job,
  Aws.Stg_Temp Temp

where
      Temp.Comp_Nm = Job.Name
  and Temp.CompTyp_Cd = 'SCHED_JOBSTREAM'
  and Temp.Comp_Corr_Val = concat('SCHED_ENGINE - ', Job.MasterName)
  and ((Temp.MsmtTyp_Nm = 'Start Delay' and timestampdiff(2, cast(Job.Actual_StartTime-Job.Planned_StartTime as char(22))) > 0) or
       (Temp.MsmtTyp_Nm = 'Duration' and  Job.Actual_Duration > 0) or
       (Temp.MsmtTyp_Nm = 'CPU Time' and Job.Cpu_Time > 0))

group by
  Temp.Comp_Id,
  Temp.MsmtTyp_Id,
  Temp.MsmtTyp_Nm,
  Temp.TmSum_Cd,
  Job.Actual_StartTime,
  Job.Planned_StartTime;


--------------------------------------------------------------------
--Insert measurements into final table
--------------------------------------------------------------------
insert into Twg.Msmt
(Comp_ID, MsmtTyp_ID, TmSum_Cd, Msmt_Strt_Dt, Msmt_Strt_Tm,
 Msmt_Min_Val, Msmt_Max_Val, Msmt_Avg_Val, Msmt_Tot_Val)
select   
      Msmt.Comp_ID,       
      Msmt.MsmtTyp_ID,
      Msmt.TmSum_Cd,    
      Msmt.Msmt_Strt_Dt,
      Msmt.Msmt_Strt_Tm,  
      Msmt.Msmt_Min_Val,  
      Msmt.Msmt_Max_Val,  
      Msmt.Msmt_Avg_Val,  
      Msmt.Msmt_Tot_Val
from                                                            
  Aws.Stage_Msmt Msmt, Twg.Extract_Control ExtCtrl
where
      ExtCtrl.ExtCtl_Source = 'TWG.MSMT'
  and ExtCtrl.ExtCtl_Target = 'AWS_Stage_TWS_Archive'
  and ExtCtrl.ExtCtl_To_DtTm < timestamp(Msmt.Msmt_Strt_Dt, Msmt.Msmt_Strt_Tm); 


--------------------------------------------------------------------
-- Refresh extract control table on last extraction date
--------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Temp_ExtCtrl;

--#EXECUTE_AT_TARGET
create table Aws.Temp_ExtCtrl
(
       ExtCtl_From_DtTm		TIMESTAMP,
       ExtCtl_To_DtTm		TIMESTAMP
);

--#EXECUTE_AT_TARGET
insert into Aws.Temp_ExtCtrl
(ExtCtl_From_DtTm, ExtCtl_To_DtTm)
select min(timestamp(M.Msmt_Strt_Dt, M.Msmt_Strt_Tm)),
       max(timestamp(M.Msmt_Strt_Dt, M.Msmt_Strt_Tm))
from Aws.Stg_Temp_Comp C, Twg.Msmt M
where C.Comp_ID = M.Comp_ID;

-- write extract info to extract log
--#EXECUTE_AT_TARGET
insert into Twg.Extract_Log
(ExtLog_Source, ExtLog_Target, ExtLog_Done_DtTm,
 ExtLog_From_RawSeq, ExtLog_To_RawSeq, ExtLog_From_IntSeq, ExtLog_To_IntSeq,
 ExtLog_From_DtTm, ExtLog_To_DtTm)
select ExtCtrl.Extctl_Source, ExtCtrl.Extctl_Target,
       current timestamp - current timezone,
       ExtCtrl.Extctl_From_Rawseq, ExtCtrl.Extctl_To_Rawseq,
       ExtCtrl.Extctl_From_Intseq, ExtCtrl.Extctl_To_Intseq,
       ExtCtrl.Extctl_From_Dttm, ExtCtrl.Extctl_To_Dttm
from Twg.Extract_Control ExtCtrl
where ExtCtrl.ExtCtl_Target ='AWS_Stage_TWS_Archive';

--#EXECUTE_AT_TARGET
update Twg.Extract_Control ExtCtrl set
ExtCtl_To_DtTm = coalesce((select TmpExtCtrl.ExtCtl_To_DtTm from Aws.Temp_ExtCtrl TmpExtCtrl), ExtCtrl.ExtCtl_To_DtTm)
where ExtCtrl.ExtCtl_Target ='AWS_Stage_TWS_Archive';

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Temp_ExtCtrl;


--------------------------------------------------------------------
-- drop staging tables
--------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_Msmt;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp_Comp;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp;


--------------------------------------------------------------------
-- drop Source staging tables
--------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Tws_WorkStation_P;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Tws_JobStream_P;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Tws_Job_P;

------------------------------------------------
-- Creating staging tables
------------------------------------------------
--#EXECUTE_AT_TARGET
create table Aws.Tws_WorkStation_P 
(
  Name  		  VARCHAR(96) not null,
  Node    		  VARCHAR(255),
  WorkstationType         VARCHAR(5),
  OperSys    		  VARCHAR(6),
  DomainName     	  VARCHAR(96),
  MasterName 		  VARCHAR(96),
  Symphony_Date           TIMESTAMP
);

--#EXECUTE_AT_TARGET
create table Aws.Tws_JobStream_P
(
  Name 			VARCHAR(96) not null,
  Priority		INTEGER,
  Status		SMALLINT,
  Planned_StartTime	TIMESTAMP,
  Actual_StartTime	TIMESTAMP,
  Actual_Duration	INTEGER,
  Cpu_Time		INTEGER, 	
  MasterName 		VARCHAR(96) not null
);

--#EXECUTE_AT_TARGET
create table Aws.Tws_Job_P
(
  Name 			VARCHAR(96) not null,
  Priority		INTEGER,
  Status		SMALLINT,
  Planned_StartTime	TIMESTAMP,
  Actual_StartTime	TIMESTAMP,
  Actual_Duration	INTEGER,
  Cpu_Time		INTEGER,
  Login			VARCHAR(48),
  Command	  	VARCHAR(120),
  MasterName 		VARCHAR(96),
  WorkstationName       VARCHAR(96) not null,
  JobstreamName 	VARCHAR(96)
);


-- done ETL1 Measurements.
