-- ****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5698-WSH
-- *
-- * (C) Copyright IBM Corp. 2002 - 2005.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- *
-- ****************************************************************************
-- *
-- * Product  : IBM Tivoli Workload Scheduler
-- *
-- * Component: Warehouse Enablement Pack
-- *
-- * File     : aws_m10_s040_martTWS.db2
-- *
-- * Purpose  : ETL2
-- *
-- ****************************************************************************
-- ETL2: Extract data from Central Database Transform and Load into Mart


------------------------------------------------------------------------
-- Prune old data from the fact table according to the values 
-- inserted into the pruning control table.
------------------------------------------------------------------------
--#EXECUTE_AT_TARGET
insert into Aws.Prune_Mart_Log
(PMart_Run_Dttm, Table_Name, PmartC_Duration, Number_Pruned)
values
(
 current timestamp - current timezone,
 'AWS.F_RUNSTATES_DAY',
 (select Ctrl.PmartC_Duration
  from Aws.Prune_Mart_Control Ctrl
  where Ctrl.Table_Name = 'AWS.F_RUNSTATES_DAY'),
 (select count(*)
  from Aws.F_RunStates_Day Fact
  where (date(current timestamp - current timezone) - date(Fact.Meas_Date)) >
                                 (select Ctrl.PmartC_Duration
                                  from Aws.Prune_Mart_Control Ctrl
                                  where Ctrl.Table_Name = 'AWS.F_RUNSTATES_DAY')));

--#EXECUTE_AT_TARGET
insert into Aws.Prune_Mart_Log
(PMart_Run_Dttm, Table_Name, PmartC_Duration, Number_Pruned)
values
(
 current timestamp - current timezone,
 'AWS.F_RUNTIMES_DAY',
 (select Ctrl.PmartC_Duration
  from Aws.Prune_Mart_Control Ctrl
  where Ctrl.Table_Name = 'AWS.F_RUNTIMES_DAY'),
 (select count(*)
  from Aws.F_RunStates_Day Fact
  where (date(current timestamp - current timezone) - date(Fact.Meas_Date)) >
                                 (select Ctrl.PmartC_Duration
                                  from Aws.Prune_Mart_Control Ctrl
                                  where Ctrl.Table_Name = 'AWS.F_RUNTIMES_DAY')));                                                      


---------------------------------------
-- Pruning fact table...
---------------------------------------
--#EXECUTE_AT_TARGET
delete from Aws.F_RunStates_Day Fact
where (date(current timestamp - current timezone) - date(Fact.Meas_Date)) >
                                 (select Ctrl.PMartC_Duration
                                  from Aws.Prune_Mart_Control Ctrl
                                  where Ctrl.Table_Name = 'AWS.F_RUNSTATES_DAY');


--#EXECUTE_AT_TARGET
delete from Aws.F_RunTimes_Day Fact
where (date(current timestamp - current timezone) - date(Fact.Meas_Date)) >
                                 (select Ctrl.PMartC_Duration
                                  from Aws.Prune_Mart_Control Ctrl
                                  where Ctrl.Table_Name = 'AWS.F_RUNTIMES_DAY');



------------------------------------------------------------------------
-- create staging table for components, atributes and relationships
------------------------------------------------------------------------
------------------------------------
-- Components
------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_Comp;

--#EXECUTE_AT_TARGET
create table Aws.Stage_Comp
(
  Comp_Id		INTEGER		not null,
  Comp_Nm		VARCHAR(254)	not null,
  CompTyp_Cd		VARCHAR(17)	not null
);

--#INSERT_INTO_TARGET
insert into Aws.Stage_Comp
--(Comp_Id, Comp_Nm, CompTyp_Cd)
select
	Comp.Comp_Id,
	Comp.Comp_Nm,
	Comp.CompTyp_Cd
from	Twg.Cur_Comp Comp
where
	Comp.CompTyp_Cd in ('SCHED_JOB', 'SCHED_JOBSTREAM',
	                    'SCHED_WORKSTATION', 'IP_HOST','SCHED_ENGINE');


------------------------------------
-- Atributes
------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompAttr;

--#EXECUTE_AT_TARGET
create table Aws.Stage_CompAttr
(
  CompAttr_Id		INTEGER		not null,
  Comp_Id		INTEGER		not null,
  AttrTyp_Cd		VARCHAR(17)	not null,
  CompAttr_Val		VARCHAR(254)	not null
);


-- temporary table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_TmpAttr;

--#EXECUTE_AT_TARGET
create table Aws.Stg_TmpAttr
(
  CompAttr_Id		INTEGER		not null,
  Comp_Id		INTEGER		not null,
  AttrTyp_Cd		VARCHAR(17)	not null,
  CompAttr_Val		VARCHAR(254)	not null
);

--#INSERT_INTO_TARGET
insert into Aws.Stg_TmpAttr
--(CompAttr_Id, Comp_Id, AttrTyp_Cd, CompAttr_Val)
select
	Attr.CompAttr_Id,
	Attr.Comp_Id,
	Attr.AttrTyp_Cd,
	Attr.CompAttr_Val
from	Twg.Cur_CompAttr Attr
where
	Attr.AttrTyp_Cd in ('SCHED_PRIORITY', 'SCHED_LOGIN', 'OS_NAME');


--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Temp
(
  CompAttr_Id		INTEGER		not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stg_Temp
(CompAttr_Id)
select
	max(CompAttr.CompAttr_Id)
from	Aws.Stg_TmpAttr CompAttr
group by
	CompAttr.Comp_Id,
	CompAttr.AttrTyp_Cd;



--#EXECUTE_AT_TARGET
insert into Aws.Stage_CompAttr
(CompAttr_Id, Comp_Id, AttrTyp_Cd, CompAttr_Val)
select
	Attr.CompAttr_Id,
	Attr.Comp_Id,
	Attr.AttrTyp_Cd,
	Attr.CompAttr_Val
from	Aws.Stg_TmpAttr Attr,
	Aws.Stg_Temp Temp
where
	Attr.CompAttr_Id = Temp.CompAttr_Id;


-- drop temporary table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_TmpAttr;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Temp;


------------------------------------
-- Relationshps
------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompReln;

--#EXECUTE_AT_TARGET
create table Aws.Stage_CompReln
(
  Comp_Source_Id	INTEGER		not null,
  Comp_Target_Id	INTEGER		not null,
  RelnTyp_Cd		VARCHAR(6)	not null
);

--#INSERT_INTO_TARGET
insert into Aws.Stage_CompReln
--(Comp_Source_Id, Comp_Target_Id, RelnTyp_Cd)
select
	Reln.Comp_Source_Id,
	Reln.Comp_Target_Id,
	Reln.RelnTyp_Cd
from	Twg.Cur_CompReln Reln
where
	Reln.RelnTyp_Cd in ('PCHILD', 'LCONT', 'RUNSON');


------------------------------------
-- Measurements
------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_Msmt;

--#EXECUTE_AT_TARGET
create table Aws.Stage_Msmt
(
 Msmt_Id		INTEGER		not null,
 Comp_Id		INTEGER		not null,
 MsmtTyp_Id		INTEGER		not null,
 Msmt_Strt_Dt		DATE		not null,
 Msmt_Strt_Tm		TIME		not null,
 Msmt_Min_Val		DOUBLE,
 Msmt_Max_Val		DOUBLE,
 Msmt_Avg_Val		DOUBLE,
 Msmt_Tot_Val		DOUBLE,
 Msmt_Smpl_Cnt		DOUBLE,
 Type_Run		CHAR(1)		not null
);


--#INSERT_INTO_TARGET
insert into Aws.Stage_Msmt
--(Msmt_Id, Comp_Id, MsmtTyp_Id, Msmt_Strt_Dt, Msmt_Strt_Tm, Msmt_Min_Val,
-- Msmt_Max_Val, Msmt_Avg_Val, Msmt_Tot_Val, Msmt_Smpl_Cnt, Type_Run)
select
	Msmt.Msmt_Id,       
	Msmt.Comp_Id,
	Msmt.MsmtTyp_Id,
	Msmt.Msmt_Strt_Dt,
	Msmt.Msmt_Strt_Tm,
	Msmt.Msmt_Min_Val,
	Msmt.Msmt_Max_Val,
	Msmt.Msmt_Avg_Val,
	Msmt.Msmt_Tot_Val,
	Msmt.Msmt_Smpl_Cnt,
	case MsmtTyp.MsmtTyp_Nm
       		when 'Duration' then 'T'
       		when 'CPU Time' then 'T'
       		when 'Start Delay' then 'T'
       		else 'S'
       	end
from
	Twg.Msmt Msmt,
	Twg.MsmtTyp MsmtTyp
where
	Msmt.TmSum_Cd = 'D'
    and Msmt.MsmtTyp_Id = MsmtTyp.MsmtTyp_Id
    and MsmtTyp.MsmtTyp_Nm in ('Number of Successful Runs',
                               'Number of Canceled Runs',
                               'Number of Unsuccessful Runs',
                               'Number of Unknown Runs',
                               'Number of Runs',
                               'Duration',
                               'CPU Time',
                               'Start Delay');


------------------------------------
-- Stage Extract Control
------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_Extract_Control;

--#EXECUTE_AT_TARGET
create table Aws.Stage_Extract_Control
(
  Extctl_Source			VARCHAR(120) not null,
  Extctl_Target			VARCHAR(120) not null,
  Extctl_From_IntSeq		BIGINT,
  Extctl_To_IntSeq		BIGINT,
  Extctl_From_Dttm		TIMESTAMP,
  Extctl_To_Dttm		TIMESTAMP
);

--#INSERT_INTO_TARGET
insert into Aws.Stage_Extract_Control
--(Extctl_Source, Extctl_Target,
-- Extctl_From_IntSeq, Extctl_To_IntSeq,
-- Extctl_From_Dttm, Extctl_To_Dttm)
select
	Ctrl.Extctl_Source,
	Ctrl.Extctl_Target,
	Ctrl.Extctl_From_IntSeq,
	Ctrl.Extctl_To_IntSeq,
	Ctrl.Extctl_From_Dttm,
	Ctrl.Extctl_To_Dttm
from
	Twg.Extract_Control Ctrl
where
	Ctrl.Extctl_Source='TWG.MSMT'
    and (Ctrl.Extctl_Target='AWS.F_RUNSTATES_DAY' or
         Ctrl.Extctl_Target='AWS.F_RUNTIMES_DAY');



------------------------------------------------------------------------
-- create staging table for Mart objects
------------------------------------------------------------------------
------------------------------------
-- Aws.D_Stage_RunStates_Metric
------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.D_Stage_RunStates_Metric;

--#EXECUTE_AT_TARGET
CREATE TABLE Aws.D_Stage_RunStates_Metric
(
  Metric_Id            INTEGER       not null,
  Met_Name             VARCHAR(254)  not null,
  Met_Desc             VARCHAR(254),
  Met_Units            VARCHAR(254)  not null,
  Met_Category         VARCHAR(254)  not null,
  Min_Exists           CHARACTER     not null,
  Max_Exists           CHARACTER     not null,
  Avg_Exists           CHARACTER     not null,
  Total_Exists         CHARACTER     not null,
  Msrc_Nm              VARCHAR(254)
);

------------------------------------
-- Aws.D_Stage_RunTimes_Metric
------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.D_Stage_RunTimes_Metric;

--#EXECUTE_AT_TARGET
create table Aws.D_Stage_RunTimes_Metric
(
  Metric_Id            INTEGER       not null,
  Met_Name             VARCHAR(254)  not null,
  Met_Desc             VARCHAR(254),
  Met_Units            VARCHAR(254)  not null,
  Met_Category         VARCHAR(254)  not null,
  Min_Exists           CHARACTER     not null,
  Max_Exists           CHARACTER     not null,
  Avg_Exists           CHARACTER     not null,
  Total_Exists         CHARACTER     not null,
  Msrc_Nm              VARCHAR(254)
);

------------------------------------
-- Aws.D_Stage_Job
------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.D_Stage_Job;

--#EXECUTE_AT_TARGET
create table Aws.D_Stage_Job
(
  Job_Id		INTEGER      not null,
  Job_Name		VARCHAR(40),
  Job_Stream_Name	VARCHAR(40) not null,
  Priority		VARCHAR(254),
  Login			VARCHAR(254)
);

------------------------------------
-- Aws.D_Stage_Workstation
------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.D_Stage_Workstation;

--#EXECUTE_AT_TARGET
create table Aws.D_Stage_Workstation
(
  Workstation_Id	INTEGER      not null,
  Name			VARCHAR(254),
  Operating_System 	VARCHAR(254),
  Ip_Host		VARCHAR(254),
  Network		VARCHAR(254)
);



------------------------------------------------------------------------
-- Insert data into staging and mart Metric tables
------------------------------------------------------------------------
-- Stage RunStates Metric Table
--#INSERT_INTO_TARGET
insert into Aws.D_Stage_RunStates_Metric
--(Metric_Id, Met_Name, Met_Desc, Met_Units, Met_Category,
-- Min_Exists, Max_Exists, Avg_Exists, Total_Exists, Msrc_Nm)
select
  MsmtTyp.MsmtTyp_Id,
  MsmtTyp.MsmtTyp_Nm,
  MsmtTyp.MsmtTyp_Ds,
  MsmtTyp.Munit_Cd,
  MsmtTyp.Munit_Cd,
  'N', 'N', 'N', 'Y',
  MsmtTyp.Msrc_Cd
from
  Twg.MsmtTyp MsmtTyp,
  Twg.Msrc Msrc
where 
      MsmtTyp.MsmtTyp_Nm in ('Number of Successful Runs',
                             'Number of Canceled Runs',
                             'Number of Unsuccessful Runs',
                             'Number of Unknown Runs',
                             'Number of Runs')
  and MsmtTyp.Msrc_Cd = Msrc.Msrc_Cd;


-- Stage RunTimes Metric Table
--#INSERT_INTO_TARGET
insert into Aws.D_Stage_RunTimes_Metric
--(Metric_Id, Met_Name, Met_Desc, Met_Units, Met_Category,
-- Min_Exists, Max_Exists, Avg_Exists, Total_Exists, Msrc_Nm)                                        
select
  MsmtTyp.MsmtTyp_Id,
  MsmtTyp.MsmtTyp_Nm,
  MsmtTyp.MsmtTyp_Ds,
  MsmtTyp.Munit_Cd,
  MsmtTyp.Munit_Cd,
  'Y', 'Y', 'Y',
  case MsmtTyp.MsmtTyp_Nm
     when 'Start Delay' then 'N'
     else 'Y'
  end,  
  MsmtTyp.Msrc_Cd
from
  Twg.MsmtTyp MsmtTyp,
  Twg.Msrc Msrc
where
      MsmtTyp.MsmtTyp_Nm in ('Duration','CPU Time','Start Delay')
  and MsmtTyp.Msrc_Cd = Msrc.Msrc_Cd;                


------------------------------------ 
-- Update the mart Metric tables
------------------------------------
-- RunStates Metric Table 
--#EXECUTE_AT_TARGET
insert into Aws.D_RunStates_Metric
(Metric_Id,Met_Name, Met_Desc, Met_Units, Met_Category,
 Min_Exists, Max_Exists, Avg_Exists, Total_Exists, Msrc_Nm)
select 
  Stage.Metric_Id, 
  Stage.Met_Name,
  Stage.Met_Desc,
  Stage.Met_Units,
  Stage.Met_Category,
  Stage.Min_Exists,
  Stage.Max_Exists,
  Stage.Avg_Exists,
  Stage.Total_Exists,
  Stage.Msrc_Nm
from  Aws.D_Stage_RunStates_Metric Stage
where not exists (select 1
                  from Aws.D_RunStates_Metric Metric
                  where Metric.Met_Name = Stage.Met_Name);         

-- RunTimes Metric Table
--#EXECUTE_AT_TARGET
insert into Aws.D_RunTimes_Metric
(Metric_Id,Met_Name, Met_Desc, Met_Units, Met_Category,
 Min_Exists, Max_Exists, Avg_Exists, Total_Exists, Msrc_Nm)
select 
  Stage.Metric_Id, 
  Stage.Met_Name,
  Stage.Met_Desc,
  Stage.Met_Units,
  Stage.Met_Category,
  Stage.Min_Exists,
  Stage.Max_Exists,
  Stage.Avg_Exists,
  Stage.Total_Exists,
  Stage.Msrc_Nm
from  Aws.D_Stage_RunTimes_Metric Stage
where not exists (select 1
                  from Aws.D_RunTimes_Metric Metric
                  where Metric.Met_Name = Stage.Met_Name);


------------------------------------------------------------------------
-- Insert data into staging and mart Dimension tables
------------------------------------------------------------------------
---------------------------------------
-- Job Dimension
---------------------------------------
-- temporary table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Job;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Job
(
  Job_Id		INTEGER		not null,
  Job_Name		VARCHAR(40),
  Job_Stream_Name	VARCHAR(40)	not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stg_Job
(Job_Id, Job_Name, Job_Stream_Name)
select distinct
	Job.Comp_Id,
	substr(Job.Comp_Nm, 1, 40),
	substr(JobStream.Comp_Nm, 1, 40)
from
 	Aws.Stage_Comp Job,
 	Aws.Stage_Comp JobStream,
	Aws.Stage_CompReln Reln
where
	Job.CompTyp_Cd = 'SCHED_JOB'
    and JobStream.CompTyp_Cd = 'SCHED_JOBSTREAM'
    and Reln.RelnTyp_Cd = 'LCONT'
    and Reln.Comp_Source_Id = Job.Comp_Id
    and Reln.Comp_Target_Id = JobStream.Comp_Id;


-- stage dimension table
--#EXECUTE_AT_TARGET
insert into Aws.D_Stage_Job
(Job_Id, Job_Name, Job_Stream_Name, Priority, Login)
select
	Job.Job_Id,
	Job.Job_Name,
	Job.Job_Stream_Name,
	Priority.CompAttr_Val,
	Login.CompAttr_Val
from
 	Aws.Stg_Job Job,
	Aws.Stage_CompAttr Priority,
	Aws.Stage_CompAttr Login
where
	Job.Job_Id = Priority.Comp_Id
    and Job.Job_Id = Login.Comp_Id
    and Priority.AttrTyp_Cd = 'SCHED_PRIORITY'
    and Login.AttrTyp_Cd = 'SCHED_LOGIN';


-- insert into mart table
--#EXECUTE_AT_TARGET
insert into Aws.D_Job
(Job_Id, Job_Name, Job_Stream_Name, Priority, Login)
select
	Stage.Job_Id,
	Stage.Job_Name,
	Stage.Job_Stream_Name,
	Stage.Priority,
	Stage.Login
from
	Aws.D_Stage_Job Stage
where
	not exists (select 1
		    from Aws.D_Job Job
		    where Job.Job_Id = Stage.Job_Id);

-- temporary table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Job;


---------------------------------------
-- Workstation Dimension
---------------------------------------
-- temporary table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Work_IpHost;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Work_IpHost
(
  Workstation_Id	INTEGER      not null,
  Name			VARCHAR(254),
  IpHost	 	VARCHAR(254)
);

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Work_Engine;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Work_Engine
(
  Workstation_Id	INTEGER      not null,
  Network		VARCHAR(254)
);

--#EXECUTE_AT_TARGET
insert into Aws.Stg_Work_IpHost
(Workstation_Id, Name, IpHost)
select distinct
	Work.Comp_Id,
	Work.Comp_Nm,
	Ip_Host.Comp_Nm
from
 	Aws.Stage_Comp Work,
 	Aws.Stage_Comp Ip_Host,
	Aws.Stage_CompReln Reln
where
	Work.CompTyp_Cd = 'SCHED_WORKSTATION'
    and Ip_Host.CompTyp_Cd = 'IP_HOST'
    and Reln.RelnTyp_Cd = 'RUNSON'
    and Reln.Comp_Source_Id = Work.Comp_Id
    and Reln.Comp_Target_Id = Ip_Host.Comp_Id;

--#EXECUTE_AT_TARGET
insert into Aws.Stg_Work_Engine
(Workstation_Id, Network)
select distinct
	Work.Comp_Id,
	Engine.Comp_Nm
from
 	Aws.Stage_Comp Work,
 	Aws.Stage_Comp Engine,
	Aws.Stage_CompReln Reln
where
	Work.CompTyp_Cd = 'SCHED_WORKSTATION'
    and Engine.CompTyp_Cd = 'SCHED_ENGINE'
    and Reln.RelnTyp_Cd = 'PCHILD'
    and Reln.Comp_Source_Id = Engine.Comp_Id
    and Reln.Comp_Target_Id = Work.Comp_Id;


-- stage dimension table
--#EXECUTE_AT_TARGET
insert into Aws.D_Stage_Workstation
(Workstation_Id, Name, Operating_System, Ip_Host, Network)
select
	WorkIH.Workstation_Id,
	WorkIH.Name,
	Os.CompAttr_Val,
	WorkIH.IpHost,
	WorkEn.Network
from
 	Aws.Stg_Work_IpHost WorkIH,
 	Aws.Stg_Work_Engine WorkEn,
	Aws.Stage_CompAttr Os
where
	WorkIH.Workstation_Id = WorkEn.Workstation_Id
    and WorkIH.Workstation_Id = Os.Comp_Id
    and Os.AttrTyp_Cd = 'OS_NAME'; 


-- insert into mart table
--#EXECUTE_AT_TARGET
insert into Aws.D_Workstation
(Workstation_id, name, operating_system, ip_host, network)
select
	Stage.Workstation_Id,
	Stage.Name,
	Stage.Operating_System,
	Stage.Ip_Host,
	Stage.Network
from
	Aws.D_Stage_Workstation Stage
where
	not exists (select 1
		    from Aws.D_Workstation Work
		    where Work.Workstation_Id = Stage.Workstation_Id);


-- temporary table
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Work_IpHost;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Work_Engine;



------------------------------------------------------------------------
-- Insert data into mart Fact tables
------------------------------------------------------------------------
-- temporary tables
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Job_Work;

--#EXECUTE_AT_TARGET
create table Aws.Stg_Job_Work
(
 Job_Id			INTEGER      not null,
 Workstation_Id		INTEGER      not null
);

--#EXECUTE_AT_TARGET
insert into Aws.Stg_Job_Work
(Job_Id, Workstation_Id)
select
	Job.Job_Id,
	max(Work.Workstation_Id)
from
 	Aws.D_Job Job,
 	Aws.D_Workstation Work,
	Aws.Stage_CompReln Reln
where
	Reln.RelnTyp_Cd = 'RUNSON'
    and Reln.Comp_Source_Id = Job.Job_Id
    and Reln.Comp_Target_Id = Work.Workstation_Id
group by
	Job.Job_Id;

-- insert values into RunStates fact table
--#EXECUTE_AT_TARGET
insert into Aws.F_RunStates_Day
(Metric_Id, Job_Id, Workstation_Id, Meas_Date, Min_Value, 
 Max_Value, Avg_Value, Total_Value, Sample_Count)
select
	Msmt.MsmtTyp_Id,
	Comp.Job_Id,
	Comp.Workstation_Id,
	timestamp(Msmt.Msmt_Strt_Dt, '00.00.00'),
	Msmt.Msmt_Min_Val,
	Msmt.Msmt_Max_Val,
	Msmt.Msmt_Avg_Val,
	Msmt.Msmt_Tot_Val,
	Msmt.Msmt_Smpl_Cnt
from
	Aws.Stg_Job_Work Comp,
	Aws.Stage_Msmt Msmt,
	Aws.Stage_Extract_Control Ctrl
where
	Msmt.Type_Run = 'S'	
    and Msmt.Comp_Id = Comp.Job_Id
    and Msmt.Msmt_Id > Ctrl.Extctl_To_IntSeq
    and Ctrl.Extctl_Source = 'TWG.MSMT'
    and Ctrl.Extctl_Target = 'AWS.F_RUNSTATES_DAY';


-- insert values into RunTimes fact table
--#EXECUTE_AT_TARGET
insert into Aws.F_RunTimes_Day
(Metric_Id, Job_Id, Workstation_Id, Meas_Date, Min_Value, 
 Max_Value, Avg_Value, Total_Value, Sample_Count)
select
	Msmt.MsmtTyp_Id,
	Comp.Job_Id,
	Comp.Workstation_Id,
	timestamp(Msmt.Msmt_Strt_Dt, '00.00.00'),
	Msmt.Msmt_Min_Val,
	Msmt.Msmt_Max_Val,
	Msmt.Msmt_Avg_Val,
	Msmt.Msmt_Tot_Val,
	Msmt.Msmt_Smpl_Cnt
from
	Aws.Stg_Job_Work Comp,
	Aws.Stage_Msmt Msmt,
	Aws.Stage_Extract_Control Ctrl
where
	Msmt.Type_Run = 'T'	
    and Msmt.Comp_Id = Comp.Job_Id
    and Msmt.Msmt_Id > Ctrl.Extctl_To_IntSeq
    and Ctrl.Extctl_Source = 'TWG.MSMT'
    and Ctrl.Extctl_Target = 'AWS.F_RUNTIMES_DAY';


-- drop temporary tables
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stg_Job_Work;



------------------------------------------------------------------------
-- Update the Extract Control and Log Tables
------------------------------------------------------------------------
---------------------------------------
-- Extract Log Table
---------------------------------------
--#INSERT_INTO_SOURCE
insert into Twg.Extract_Log
--(ExtLog_Source, ExtLog_Target, ExtLog_Done_DtTm,
-- ExtLog_From_IntSeq, ExtLog_To_IntSeq, ExtLog_From_DtTm, ExtLog_To_DtTm)
select
	Ctrl.Extctl_Source,
	Ctrl.Extctl_Target,
	current timestamp - current timezone,
	x'', x'',
	Ctrl.Extctl_From_Intseq, Ctrl.Extctl_To_Intseq,
	Ctrl.Extctl_From_Dttm, Ctrl.Extctl_To_Dttm
from Aws.Stage_Extract_Control Ctrl;


---------------------------------------
-- Extract Control Table
---------------------------------------
-- temporary table
--#IGNORE_ERROR
drop table Aws.Temp_MaxDate;

create table Aws.Temp_MaxDate
(
  Dttm			TIMESTAMP,
  Target		VARCHAR(120)
);

--#INSERT_INTO_SOURCE
insert into Aws.Temp_MaxDate
--(Dttm, Target)
select
	max(States.Meas_Date),
	'AWS.F_RUNSTATES_DAY'
from
	Aws.F_RunStates_Day States
union
select
	max(States.Meas_Date),
	'AWS.F_RUNTIMES_DAY'
from
	Aws.F_RunTimes_Day States;


--#IGNORE_ERROR
drop table Aws.Temp_Max;

create table Aws.Temp_Max
(
  Msmt_Id		INTEGER,
  Dttm			TIMESTAMP,
  Target		VARCHAR(120)
);

insert into Aws.Temp_Max
(Msmt_Id, Dttm, Target)
select
	max(Msmt.Msmt_Id),
	Temp.Dttm,
	Temp.Target
from
	Twg.Msmt Msmt,
	Aws.Temp_MaxDate Temp
where
	Temp.Dttm <= timestamp(Msmt.Msmt_Strt_Dt, Msmt.Msmt_Strt_Tm)
group by
	Temp.Dttm,
	Temp.Target;


update Twg.Extract_Control Ctrl set
Extctl_To_Intseq = coalesce((select TempId.Msmt_Id
                             from Aws.Temp_Max TempId
                             where Ctrl.Extctl_Target = TempId.Target),
                            Ctrl.Extctl_To_Intseq),
Extctl_To_Dttm = coalesce((select TempDate.Dttm
                           from Aws.Temp_Max TempDate
                           where Ctrl.Extctl_Target = TempDate.Target),
                          timestamp('1970-01-01-00.00.00.000000'))
where
	Ctrl.Extctl_Source = 'TWG.MSMT'
    and (Ctrl.Extctl_Target = 'AWS.F_RUNSTATES_DAY' or
         Ctrl.Extctl_Target = 'AWS.F_RUNTIMES_DAY');


-- drop temporary table
--#IGNORE_ERROR
drop table Aws.Temp_Max;

--#IGNORE_ERROR
drop table Aws.Temp_MaxDate;



------------------------------------------------------------------------
-- drop CDW staging tables
------------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_Comp;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompAttr;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_CompReln;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_Msmt;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.Stage_Extract_Control;



------------------------------------------------------------------------
-- drop MART staging tables
------------------------------------------------------------------------
--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.D_Stage_RunStates_Metric;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.D_Stage_RunTimes_Metric;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.D_Stage_Job;

--#IGNORE_ERROR
--#EXECUTE_AT_TARGET
drop table Aws.D_Stage_Workstation;


-- done ETL2