#!/bin/sh
######################################################################
#
# Tivoli Enterprise Data Warehouse, v 1.1.0
# (C) Copyright IBM Corp. 2002.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with
# IBM Corp.
#
#
#######################################################################
#
# File Information: src/rpi/schema/app_after.sh, twh_rpi, twh_1.1_ode
#
# Revision: 1.4
#
# Date: 7/17/02 15:01:58
#
# Desc:  This is the template for WPack application after scripts.
#        It is intended to be used by WPack's that have additional
#        activities needed during the WPack installation, but that
#        there is no default logic in the WPack installer to handle.
#        There is a hook to execute a Core after script that is
#        required to allow dynamic patching of the WPack install
#        process.  Do not remove this hook.
#
#       NOTE - This after script only runs on the Control Server
#              and not on other distributed hosts.
#
# Command Line Args:
#       1 = the path and name of the TWH Application config file
#       2 = Application working directory or install base directory
#               $TWH_TOPDIR/apps/ava_code_for_app/vapp_version
#               (look at install tree)
#
# Required Config File:
#       twh_app_install.cfg
#
# Installation Logs (Default names):
#       A log will be generated for this scirpt called
#       <ava>_after.sh.log
#
#
# Required Env Vars:
#       TWH_TOPDIR
#
# Return Codes (Only!):
#       0 = Success
#       255 = Failure
#
# Interpreter Required:
#       NT/2000 = BASH
#       Unix    = SH (Bourne Shell)
#
#
# Message Types:
#       (I) - Informational
#       (W) - Warning
#       (F) - Fatal
#
# Install Steps Required Before this Script Executes:
#        * TWH Core tools components must be successfully installed
#
# Note - Caution needs to be taken for NT paths that have a space.
#        This is a limitation that requires double quoting around all
#        variables that contain a path.  Testing should be done to
#        ensure this script runs with a space in any of the paths 
#        that are used.  For example "c:/program files".
#
######################################################################
#

echo "                ** After Script Log **"
echo ""
echo "****************************************"
echo "* Application After Script Start point *"
echo "****************************************"

# Set parms
echo "      Parm 1 = $1"; TWH_CONFIG_FILE="$1"; export TWH_CONFIG_FILE
echo "      Parm 2 = $2"; APP_WORK_DIR="$2"; export APP_WORK_DIR
echo ""

# TWH_TOPDIR needs to always be in the environment
if [ -z "$TWH_TOPDIR" ]; then
  echo "      (F) Could not locate Env var TWH_TOPDIR"
  exit 255
fi

# Execute startup driver for afterscript
. "$TWH_TOPDIR"/install/bin/twh_core_startup_after.sh
exec_startup_driver;

#####################################################
######## Add application code below here ONLY #######
#####################################################


your_method1()
{
#echo "==> WPack Method 1 executing"

return 0;
}

set_aws_program_vars()
{

# name of the temporary sql file
tmp_sql_file="aws_tmp_sql.sql"

# prune value (yyyymmdd)
prune_value=10000

# string of the temporary sql file
tmp_sql_AWS="update TWG.PRUNE_MSMT_CONTROL set PMSMTC_AGE_IN_DAYS=$prune_value where TMSUM_CD='D' and MSRC_CD='AWS';
             update TWG.EXTRACT_CONTROL set EXTCTL_TO_DTTM = timestamp('1970-01-01-00.00.00.000000')
             where EXTCTL_SOURCE='TWG.MSMT' and EXTCTL_TARGET in ('AWS.F_RUNSTATES_DAY', 'AWS.F_RUNTIMES_DAY', 'AWS_Stage_TWS_Archive')
             and EXTCTL_TO_DTTM >= timestamp('9999-01-01-00.00.00.000000');"

TRUE=1
FALSE=0

return 0
}


update_control_tables()
{
  echo "==> Update control tables"
	
  # Test a connection
  echo "      (I) Testing the DB connection"
  
  err_txt=`$DB2EXEC_LOG connect to "$TWH_CDW_DB" user "$COPT_CDW_DB2USER" using "$COPT_CDW_DB2PASS" 2>&1 `
  if [ $? -ne 0 ]; then
    echo "      (F) Unable to connect to database ($TWH_CDW_DB)."
    echo "          Error is:"
    echo "          $err_txt"
    echo "          Exiting..."
    exit 255
  fi

  # Update it...
  echo "      (I) update control tables"
  
  echo "$tmp_sql_AWS" > "$TMPDIR/$tmp_sql_file"
  
  gr_build_exec_script "$TWH_CDW_DB" "$TMPDIR" "$tmp_sql_file" $COPT_CDW_TYPE $CONN_TYPE_CONNECT
  gr_exec_sql_script "$TWH_CDW_DB" $TRUE

  rm -f "$TMPDIR/$tmp_sql_file"
  
  echo "      (I) Done update "

  return 0
}


remove_old_sql_files()
{
echo "==> WPack Method remove_old_sql_files executing"

#these are the files that will remove in the TEDW patch 1
DELETE_IT="aws_clean_and_reset.sql aws_clean_mart.sql"

echo "APP_WORK_DIR = $APP_WORK_DIR"
echo "to delete $DELETE_IT"
APP_WORK_DIR=`echo $APP_WORK_DIR | tr \"\\\\\" "/"`
echo "APP_WORK_DIR = $APP_WORK_DIR"

for var in $DELETE_IT; do
echo "To delete $APP_WORK_DIR/misc/$var"
if [ -f "$APP_WORK_DIR/misc/$var" ]
then
	rm -f "$APP_WORK_DIR/misc/$var" 
	echo "delete $APP_WORK_DIR/misc/$var"
fi
done

return 0
}


################
# Main section #
################
echo "==> Processing main WPack routines"
echo ""

# Call your routines
# your_method1;
set_aws_program_vars;
remove_old_sql_files;
update_control_tables;

echo ""
echo "      (I) Done processing main WPack routines"
#####################################
## Stop adding application code #####
#####################################
exec_core_after;		# DO NOT MOVE OR REMOVE!


echo ""
echo "==> Completed executing application after script"
exit 0
