-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #	
-- #  (C) Copyright IBM Corp. 2002 - 2005  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- #
-- ############################################################################

----------------------------------------------------------------
--RUN INSTRUCTIONS:
--    1. Open a DB2 command window.
--    2. Connect to TWH_CDW database by using the following command:
--	 db2 connect to twh_cdw user <db_user> using <db_password>
--	 where 	 <db_user>, <db_password> specify datbase user and password
--    2. Enter the following command
--      
--       db2 -f aws_clean_and_reset.db2 -t -r output.txt -l errorlog.txt
--
--       Note: aws_clean_and_reset.db2 is the name of this file.
--             output.txt   is the output report filename.
--             errorlog.txt is the error log filename.
--
---------------------------------------------------------------------------------
-- Drop measurements, components, component attributes
---------------------------------------------------------------------------------


declare global temporary table session.CompToDelete
(Comp_id INTEGER) with replace on commit preserve rows not logged;


INSERT INTO session.CompToDelete
	SELECT DISTINCT COMP_ID FROM TWG.MSMT WHERE MSMTTYP_ID in (SELECT MSMTTYP_ID FROM TWG.MSMTTYP WHERE MSRC_CD='AWS' OR (MSMTTYP_NM='Number of Runs' OR MSMTTYP_NM='Number of Unsuccessful Runs' OR MSMTTYP_NM='Duration') )
;
INSERT INTO session.CompToDelete
	SELECT DISTINCT COMP_ID FROM TWG.COMP  where 	COMPTYP_CD IN('SCHED_ENGINE', 'SCHED_WORKSTATION', 'SCHED_JOB', 'SCHED_JOBSTREAM')
; 
DELETE FROM TWG.COMPRELN WHERE
      	COMP_SOURCE_ID IN (Select Comp_id from session.CompToDelete)
	OR 
		COMP_TARGET_ID IN (Select Comp_id from session.CompToDelete)
;

DELETE FROM TWG.COMPATTR WHERE 
	COMP_ID IN(Select Comp_id from session.CompToDelete)
;

DELETE FROM TWG.MSMT
	WHERE COMP_ID in (SELECT COMP_ID FROM session.CompToDelete)
;


DELETE FROM TWG.COMP WHERE 
	COMP_ID IN(SELECT COMP_ID FROM session.CompToDelete)
;

 
-----------------------------------------------------------------
-- Delete from staging tables
-----------------------------------------------------------------
DELETE FROM AWS.TWS_WORKSTATION_P;
DELETE FROM AWS.TWS_JOB_P;
DELETE FROM AWS.TWS_JOBSTREAM_P;
 

-----------------------------------------------------------------
-- Reset data from Extract_Control and Prune_Msmt_Control  table
-----------------------------------------------------------------


DELETE FROM TWG.Prune_Msmt_Control WHERE (MSRC_CD='AWS');

insert into TWG.Prune_Msmt_Control values ('AWS','H',31);
insert into TWG.Prune_Msmt_Control values ('AWS','D',10000);
insert into TWG.Prune_Msmt_Control values ('AWS','W',10000);
insert into TWG.Prune_Msmt_Control values ('AWS','M',10000);



---------------------------------------
-- reset data for Extract Control
---------------------------------------


delete from TWG.extract_control where ExtCtl_Target='AWS_Stage_TWS_Archive';
delete from TWG.extract_control where ExtCtl_Target='AWS.F_RUNTIMES_DAY';
delete from TWG.extract_control where ExtCtl_Target='AWS.F_RUNSTATES_DAY';


declare global temporary table Extract_Control (
	ExtCtl_Source        	varchar(120) not null,
 	ExtCtl_Target   	      varchar(120) not null,
 	ExtCtl_From_RawSeq      char(10) for bit data,
 	ExtCtl_To_RawSeq        char(10) for bit data,
 	ExtCtl_From_IntSeq      bigint,
 	ExtCtl_To_IntSeq        bigint,
 	ExtCtl_From_DtTm     	timestamp not null,
 	ExtCtl_To_DtTm       	timestamp not null
	)
with replace on commit preserve rows not logged
;

insert into session.Extract_control values (
    'TWG.MSMT' ,
    'AWS.F_RUNSTATES_DAY',
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '1970-01-01-00.00.00.000000'
);

insert into session.Extract_control values (
    'TWG.MSMT' ,
    'AWS.F_RUNTIMES_DAY',
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '1970-01-01-00.00.00.000000'
);

insert into session.Extract_control values (
    'TWG.MSMT' ,
    'AWS_Stage_TWS_Archive',
    x'',
    x'',
    0,
    0,
    '1970-01-01-00.00.00.000000',
    '1970-01-01-00.00.00.000000'
);

-- insert the static data for the extract table 
-- if not exist already
insert into TWG.Extract_control
(ExtCtl_Source, ExtCtl_Target, ExtCtl_From_RawSeq, ExtCtl_To_RawSeq,
 ExtCtl_From_IntSeq, ExtCtl_To_IntSeq, ExtCtl_From_DtTm, ExtCtl_To_DtTm)

select 
 m.ExtCtl_Source as ExtCtl_Source,
 m.ExtCtl_Target as ExtCtl_Target,
 m.ExtCtl_From_RawSeq as ExtCtl_From_RawSeq,
 m.ExtCtl_To_RawSeq as ExtCtl_To_RawSeq,
 m.ExtCtl_From_IntSeq as ExtCtl_From_IntSeq,
 m.ExtCtl_To_IntSeq as ExtCtl_To_IntSeq,
 m.ExtCtl_From_DtTm as ExtCtl_From_DtTm,
 m.ExtCtl_To_DtTm as ExtCtl_To_DtTm  
from 
 session.Extract_Control m
where not exists
( select 1 from
  TWG.Extract_Control t
  where
  t.ExtCtl_Source=m.ExtCtl_Source  and
  t.ExtCtl_Target=m.ExtCtl_Target
)
; 

