-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #	
-- #  (C) Copyright IBM Corp. 2002 - 2005  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- #
-- ############################################################################

----------------------------------------------------------------
-- RUN INSTRUCTIONS (execsql2 TDW tool):
--    1. Open a command window.
--    2. Enter the following command
--      
--       execsql2 -n aws_extract_control_reset -s TWH_CDW -u userCDW -p pswdCW -t TWH_MART -v userMart -w pswdMart -o output
--
--       Note: aws_extract_control_reset is the name of this file without the extention db2.
--             TWH_CDW	is the name of CDW database (default TWH_CDW)
--             userCDW	is the db2 administrator user of CDW (default db2admin or db2inst1)
--             pswdCDW	is the password of the CDW user
--             TWH_MART	is the name of Data Mart database (default TWH_MART)
--             userMART	is the db2 administrator user of MART (default db2admin or db2inst1)
--             pswdMART	is the password of the MART user
--             output	is the output file with the path (for example: C:\log\aws_extract_control_reset.txt)
----------------------------------------------------------------


--------------------------------------------------------------------
-- Reset Extract Control Table for ETL1
--------------------------------------------------------------------
---------------------------------------
-- temporary table for AWS Components
---------------------------------------
declare global temporary table session.Stg_Temp_Comp
(
       Comp_Id              INTEGER not null
) with replace on commit preserve rows not logged;

insert into session.Stg_Temp_Comp
(Comp_Id)
select
	Comp_Id
from
	Twg.Cur_Comp
where
	CompTyp_Cd = 'SCHED_JOB'
     or CompTyp_Cd = 'SCHED_JOBSTREAM';

---------------------------------------
-- temporary table for last extraction date
---------------------------------------
declare global temporary table session.Temp_ExtCtrl
(
       ExtCtl_To_DtTm		TIMESTAMP
) with replace on commit preserve rows not logged;

insert into session.Temp_ExtCtrl
(ExtCtl_To_DtTm)
select max(timestamp(M.Msmt_Strt_Dt, M.Msmt_Strt_Tm))
from session.Stg_Temp_Comp C, Twg.Msmt M
where C.Comp_ID = M.Comp_ID;

---------------------------------------
-- write extract info to extract control
---------------------------------------
update Twg.Extract_Control ExtCtrl set
ExtCtl_From_DtTm = timestamp('1970-01-01-00.00.00.000000'),
ExtCtl_To_DtTm = coalesce((select TmpExtCtrl.ExtCtl_To_DtTm from session.Temp_ExtCtrl TmpExtCtrl), timestamp('1970-01-01-00.00.00.000000'))
where
	ExtCtrl.ExtCtl_Source = 'TWG.MSMT' 
    and ExtCtrl.ExtCtl_Target = 'AWS_Stage_TWS_Archive';


--------------------------------------------------------------------
-- Reset Extract Control Table for ETL2
--------------------------------------------------------------------
---------------------------------------
-- temporary table for AWS Measurements
---------------------------------------
--#IGNORE_ERROR
drop table Aws.Temp_MaxDate;

create table Aws.Temp_MaxDate
(
  Dttm			TIMESTAMP,
  Target		VARCHAR(120)
);

--#INSERT_INTO_SOURCE
insert into Aws.Temp_MaxDate
(Dttm, Target)
select
	max(States.Meas_Date),
	'AWS.F_RUNSTATES_DAY'
from
	Aws.F_RunStates_Day States
union
select
	max(States.Meas_Date),
	'AWS.F_RUNTIMES_DAY'
from
	Aws.F_RunTimes_Day States;

declare global temporary table session.Temp_Max
(
  Msmt_Id		INTEGER,
  Dttm			TIMESTAMP,
  Target		VARCHAR(120)
) with replace on commit preserve rows not logged;

insert into session.Temp_Max
(Msmt_Id, Dttm, Target)
select
	max(Msmt.Msmt_Id),
	Temp.Dttm,
	Temp.Target
from
	Twg.Msmt Msmt,
	Aws.Temp_MaxDate Temp
where
	Temp.Dttm <= timestamp(Msmt.Msmt_Strt_Dt, Msmt.Msmt_Strt_Tm)
group by
	Temp.Dttm,
	Temp.Target;

--#IGNORE_ERROR
drop table Aws.Temp_MaxDate;

---------------------------------------
-- write extract info to extract control
---------------------------------------
update Twg.Extract_Control Ctrl set
Extctl_From_Intseq = 0,
Extctl_To_Intseq = coalesce((select TempId.Msmt_Id
                             from session.Temp_Max TempId
                             where Ctrl.Extctl_Target = TempId.Target),
                            0),
Extctl_From_Dttm = timestamp('1970-01-01-00.00.00.000000'),
Extctl_To_Dttm = coalesce((select TempDate.Dttm
                           from session.Temp_Max TempDate
                           where Ctrl.Extctl_Target = TempDate.Target),
                          timestamp('1970-01-01-00.00.00.000000'))
where
	Ctrl.Extctl_Source = 'TWG.MSMT'
    and (Ctrl.Extctl_Target = 'AWS.F_RUNSTATES_DAY' or
         Ctrl.Extctl_Target = 'AWS.F_RUNTIMES_DAY');


-- done.

